package mimemagic

const (
	unknownType      = 30
	emptyDocument    = 522
	plainText        = 827
	unknownDirectory = 698
	unknownXML       = 527
)

var mediaTypes = []MediaType{
	{"all", "all", "all files and folders", "", "", "", "", nil, nil, nil, nil},
	{"all", "allfiles", "all files", "", "", "", "", nil, nil, nil, nil},
	{"application", "andrew-inset", "ATK inset", "ATK", "Andrew Toolkit", "", "x-office-document", nil, nil, []string{".ez"}, nil},
	{"application", "annodex", "Annodex exchange format", "", "", "", "video-x-generic", []string{"application/x-annodex"}, nil, []string{".anx"}, nil},
	{"application", "atom+xml", "Atom syndication feed", "", "", "", "text-html", nil, []string{"application/xml"}, []string{".atom"}, []int{527}},
	{"application", "base64", "Base64 encoded data", "", "", "", "text-x-hex", nil, []string{"text/plain"}, []string{".base64", ".b64"}, []int{827}},
	{"application", "btoa", "Btoa Encoded File", "", "", "", "text-x-hex", nil, []string{"text/plain"}, []string{".b2a", ".btoa"}, []int{827}},
	{"application", "dicom", "DICOM image", "DICOM", "Digital Imaging and Communications in Medicine", "", "image-x-generic", nil, nil, []string{".dcm"}, nil},
	{"application", "ecmascript", "ECMAScript program", "", "", "", "text-x-script", []string{"text/ecmascript"}, []string{"application/x-executable", "text/plain"}, []string{".es"}, []int{255, 827}},
	{"application", "epub+zip", "electronic book document", "", "", "", "x-office-document", nil, []string{"application/zip"}, []string{".epub"}, []int{533}},
	{"application", "geo+json", "GeoJSON geospatial data", "", "", "", "", []string{"application/vnd.geo+json"}, []string{"application/json"}, []string{".geojson", ".geo.json"}, []int{18}},
	{"application", "gml+xml", "GML document", "GML", "Geography Markup Language", "", "", nil, []string{"application/xml"}, []string{".gml"}, []int{527}},
	{"application", "gnunet-directory", "GNUnet search file", "", "", "", "", nil, nil, []string{".gnd"}, nil},
	{"application", "gpx+xml", "GPX geographic data", "GPX", "GPS Exchange Format", "", "application-vnd-google-earth-kml", []string{"application/gpx", "application/x-gpx+xml", "application/x-gpx"}, []string{"application/xml"}, []string{".gpx"}, []int{527}},
	{"application", "gzip", "Gzip archive", "", "", "", "package-x-generic", []string{"application/x-gzip"}, nil, []string{".gz"}, nil},
	{"application", "illustrator", "Adobe Illustrator document", "", "", "", "image-x-generic", []string{"application/vnd.adobe.illustrator"}, nil, []string{".ai"}, nil},
	{"application", "javascript", "JavaScript program", "", "", "", "text-x-script", []string{"application/x-javascript", "text/javascript"}, []string{"application/ecmascript"}, []string{".js", ".jsm", ".mjs"}, []int{8}},
	{"application", "jrd+json", "JRD document", "JRD", "JSON Resource Descriptor", "", "text-x-script", nil, []string{"application/json"}, []string{".jrd"}, []int{18}},
	{"application", "json", "JSON document", "JSON", "JavaScript Object Notation", "", "text-x-script", nil, []string{"application/javascript"}, []string{".json"}, []int{16}},
	{"application", "json-patch+json", "JSON patch", "JSON", "JavaScript Object Notation", "", "text-x-script", nil, []string{"application/json"}, []string{".json-patch"}, []int{18}},
	{"application", "ld+json", "JSON-LD document", "JSON-LD", "JavaScript Object Notation for Linked Data", "", "text-x-script", nil, []string{"application/json"}, []string{".jsonld"}, []int{18}},
	{"application", "mac-binhex40", "Macintosh BinHex-encoded file", "", "", "", "package-x-generic", nil, nil, nil, nil},
	{"application", "mathematica", "Mathematica Notebook", "", "", "", "x-office-document", []string{"application/x-mathematica"}, []string{"text/plain"}, []string{".nb"}, []int{827}},
	{"application", "mathml+xml", "MathML document", "MathML", "Mathematical Markup Language", "", "", []string{"text/mathml"}, []string{"application/xml"}, []string{".mml"}, []int{527}},
	{"application", "mbox", "mailbox file", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".mbox"}, []int{827}},
	{"application", "metalink+xml", "Metalink file", "", "", "", "", nil, []string{"application/xml"}, []string{".metalink"}, []int{527}},
	{"application", "metalink4+xml", "Metalink file", "", "", "", "", nil, []string{"application/xml"}, []string{".meta4"}, []int{527}},
	{"application", "msword", "Word document", "", "", "", "x-office-document", []string{"application/vnd.ms-word", "application/x-msword", "zz-application/zz-winassoc-doc"}, []string{"application/x-ole-storage"}, []string{".doc"}, []int{398}},
	{"application", "msword-template", "Word template", "", "", "", "x-office-document", nil, []string{"application/msword"}, []string{".dot"}, []int{27}},
	{"application", "mxf", "MXF video", "MXF", "Material Exchange Format", "", "video-x-generic", nil, nil, []string{".mxf"}, nil},
	{"application", "octet-stream", "unknown", "", "", "", "", nil, nil, nil, nil},
	{"application", "oda", "ODA document", "ODA", "Office Document Architecture", "", "x-office-document", nil, nil, []string{".oda"}, nil},
	{"application", "ogg", "Ogg multimedia file", "", "", "", "video-x-generic", []string{"application/x-ogg"}, nil, []string{".ogx"}, nil},
	{"application", "owl+xml", "OWL XML file", "OWL", "Web Ontology Language", "", "", nil, []string{"application/xml"}, []string{".owx"}, []int{527}},
	{"application", "oxps", "XPS document", "XPS", "Open XML Paper Specification", "", "x-office-document", []string{"application/vnd.ms-xpsdocument", "application/xps"}, []string{"application/zip"}, []string{".oxps", ".xps"}, []int{533}},
	{"application", "pdf", "PDF document", "PDF", "Portable Document Format", "", "x-office-document", []string{"application/x-pdf", "image/pdf", "application/acrobat", "application/nappdf"}, nil, []string{".pdf"}, nil},
	{"application", "pgp-encrypted", "PGP/MIME-encrypted message header", "", "", "", "text-x-generic", []string{"application/pgp"}, []string{"text/plain"}, []string{".pgp", ".gpg", ".asc"}, []int{827}},
	{"application", "pgp-keys", "PGP keys", "PGP", "Pretty Good Privacy", "", "text-x-generic", nil, []string{"text/plain"}, []string{".skr", ".pkr", ".asc", ".pgp", ".gpg"}, []int{827}},
	{"application", "pgp-signature", "detached OpenPGP signature", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".asc", ".sig", ".pgp", ".gpg"}, []int{827}},
	{"application", "pkcs10", "PKCS#10 certification request", "PKCS", "Public-Key Cryptography Standards", "", "text-x-generic", nil, nil, []string{".p10", ".csr"}, nil},
	{"application", "pkcs10+pem", "PKCS#10 Certificate Request in PEM format", "", "", "", "", nil, []string{"application/x-pem-file"}, nil, []int{407}},
	{"application", "pkcs12", "PKCS#12 certificate bundle", "PKCS", "Public-Key Cryptography Standards", "", "", []string{"application/x-pkcs12"}, nil, []string{".p12", ".pfx"}, nil},
	{"application", "pkcs12+pem", "PKCS#12 Personal Key and Certificates in PEM format", "", "", "", "", nil, []string{"application/x-pem-file"}, nil, []int{407}},
	{"application", "pkcs7-mime", "PKCS#7 Message or Certificate", "PKCS", "Public-Key Cryptography Standards", "", "text-x-generic", []string{"application/x-pkcs7-certificates"}, nil, []string{".p7c", ".p7m", ".spc", ".p7b"}, nil},
	{"application", "pkcs7-mime+pem", "PKCS#7 Message and Certificates in PEM format", "", "", "", "", nil, []string{"application/x-pem-file"}, nil, []int{407}},
	{"application", "pkcs7-signature", "detached S/MIME signature", "S/MIME", "Secure/Multipurpose Internet Mail Extensions", "", "text-x-generic", nil, []string{"text/plain"}, []string{".p7s"}, []int{827}},
	{"application", "pkcs8", "PKCS#8 private key", "PKCS", "Public-Key Cryptography Standards", "", "", nil, nil, []string{".p8", ".pkcs8"}, nil},
	{"application", "pkcs8+pem", "PKCS#8 Personal Key in PEM format", "", "", "", "", nil, []string{"application/x-pem-file"}, nil, []int{407}},
	{"application", "pkcs8-encrypted", "PKCS#8 private key (encrypted)", "PKCS", "Public-Key Cryptography Standards", "", "", nil, nil, []string{".p8e"}, nil},
	{"application", "pkix-cert", "X.509 certificate", "", "", "", "", []string{"application/x-x509-ca-cert", "application/x-x509-user-cert"}, nil, []string{".cer", ".crt", ".cert"}, nil},
	{"application", "pkix-cert+pem", "X.509 Certificate in PEM format", "", "", "", "", nil, []string{"application/x-pem-file"}, nil, []int{407}},
	{"application", "pkix-crl", "Certificate revocation list", "CRL", "Certificate Revocation List", "", "", nil, nil, []string{".crl"}, nil},
	{"application", "pkix-crl+pem", "Certificate Revocation List in PEM format", "", "", "", "", nil, []string{"application/x-pem-file"}, nil, []int{407}},
	{"application", "pkix-pkipath", "PkiPath certification path", "", "", "", "", nil, nil, []string{".pkipath"}, nil},
	{"application", "postscript", "PS document", "PS", "PostScript", "", "x-office-document", nil, []string{"text/plain"}, []string{".ps"}, []int{827}},
	{"application", "prs.plucker", "Plucker document", "", "", "", "x-office-document", nil, nil, nil, nil},
	{"application", "ram", "RealMedia Metafile", "", "", "", "", nil, nil, []string{".ram"}, nil},
	{"application", "raml+yaml", "RAML document", "RAML", "RESTful API Modeling Language", "", "", nil, []string{"application/x-yaml"}, []string{".raml"}, []int{521}},
	{"application", "rdf+xml", "RDF file", "RDF", "Resource Description Framework", "", "", []string{"text/rdf"}, []string{"application/xml"}, []string{".rdf", ".rdfs", ".owl"}, []int{527}},
	{"application", "relax-ng-compact-syntax", "RELAX NG XML schema", "RELAX NG", "REgular LAnguage for XML Next Generation", "", "text-x-generic", []string{"application/x-rnc"}, []string{"text/plain"}, []string{".rnc"}, []int{827}},
	{"application", "relaxng", "RELAX NG", "", "", "", "", nil, []string{"application/xml"}, []string{".rng"}, []int{527}},
	{"application", "rss+xml", "RSS summary", "RSS", "RDF Site Summary", "", "text-html", []string{"text/rss"}, []string{"application/xml"}, []string{".rss"}, []int{527}},
	{"application", "rtf", "RTF document", "RTF", "Rich Text Format", "", "x-office-document", []string{"text/rtf"}, []string{"text/plain"}, []string{".rtf"}, []int{827}},
	{"application", "sdp", "SDP multicast stream file", "SDP", "Session Description Protocol", "", "video-x-generic", []string{"application/x-sdp", "application/vnd.sdp"}, []string{"text/plain"}, []string{".sdp"}, []int{827}},
	{"application", "sieve", "Sieve mail filter script", "", "", "", "text-x-script", nil, []string{"application/xml"}, []string{".siv"}, []int{527}},
	{"application", "smil+xml", "SMIL document", "SMIL", "Synchronized Multimedia Integration Language", "", "video-x-generic", []string{"application/smil"}, []string{"application/xml"}, []string{".smil", ".smi", ".sml", ".kino"}, []int{527}},
	{"application", "sql", "SQL code", "", "", "", "", []string{"text/x-sql"}, []string{"text/plain"}, []string{".sql"}, []int{827}},
	{"application", "trig", "TriG RDF document", "TriG", "TriG RDF Graph Triple Language", "", "", []string{"application/x-trig"}, []string{"text/plain"}, []string{".trig"}, []int{827}},
	{"application", "vnd.adobe.flash.movie", "Shockwave Flash file", "", "", "", "video-x-generic", []string{"application/x-shockwave-flash", "application/futuresplash"}, nil, []string{".swf", ".spl"}, nil},
	{"application", "vnd.android.package-archive", "Android package", "", "", "", "", nil, []string{"application/x-java-archive"}, []string{".apk"}, []int{310}},
	{"application", "vnd.appimage", "AppImage application bundle", "", "", "", "application-x-executable", nil, []string{"application/x-executable", "application/vnd.squashfs"}, []string{".appimage"}, []int{255, 163}},
	{"application", "vnd.apple.mpegurl", "HTTP Live Streaming playlist", "", "", "", "", nil, []string{"text/plain"}, []string{".m3u", ".m3u8"}, []int{827}},
	{"application", "vnd.chess-pgn", "PGN chess game notation", "PGN", "Portable Game Notation", "", "text-x-generic", []string{"application/x-chess-pgn"}, []string{"text/plain"}, []string{".pgn"}, []int{827}},
	{"application", "vnd.coffeescript", "CoffeeScript document", "", "", "", "text-x-script", nil, []string{"text/plain"}, []string{".coffee"}, []int{827}},
	{"application", "vnd.comicbook+zip", "comic book archive", "", "", "", "x-office-document", []string{"application/x-cbz"}, []string{"application/zip"}, []string{".cbz"}, []int{533}},
	{"application", "vnd.comicbook-rar", "comic book archive", "", "", "", "x-office-document", []string{"application/x-cbr"}, []string{"application/vnd.rar", "application/x-rar"}, []string{".cbr"}, []int{159}},
	{"application", "vnd.corel-draw", "Corel Draw drawing", "", "", "", "image-x-generic", []string{"application/cdr", "application/coreldraw", "application/x-cdr", "application/x-coreldraw", "image/cdr", "image/x-cdr", "zz-application/zz-winassoc-cdr"}, nil, []string{".cdr"}, nil},
	{"application", "vnd.debian.binary-package", "Debian package", "", "", "", "package-x-generic", []string{"application/x-deb", "application/x-debian-package"}, nil, []string{".deb", ".udeb"}, nil},
	{"application", "vnd.emusic-emusic_package", "eMusic download package", "", "", "", "package-x-generic", nil, nil, []string{".emp"}, nil},
	{"application", "vnd.flatpak", "Flatpak application bundle", "", "", "", "package-x-generic", []string{"application/vnd.xdgapp"}, nil, []string{".flatpak", ".xdgapp"}, nil},
	{"application", "vnd.flatpak.ref", "Flatpak repository reference", "", "", "", "package-x-generic", nil, []string{"text/plain"}, []string{".flatpakref"}, []int{827}},
	{"application", "vnd.flatpak.repo", "Flatpak repository description", "", "", "", "package-x-generic", nil, []string{"text/plain"}, []string{".flatpakrepo"}, []int{827}},
	{"application", "vnd.font-fontforge-sfd", "Fontforge Spline Font Database", "", "", "", "", nil, []string{"text/plain"}, []string{".sfd"}, []int{827}},
	{"application", "vnd.framemaker", "Adobe FrameMaker document", "", "", "", "x-office-document", []string{"application/x-frame"}, nil, []string{".fm"}, nil},
	{"application", "vnd.google-earth.kml+xml", "KML geographic data", "KML", "Keyhole Markup Language", "", "", nil, []string{"application/xml"}, []string{".kml"}, []int{527}},
	{"application", "vnd.google-earth.kmz", "KML geographic compressed data", "KML", "Keyhole Markup Language", "", "", nil, []string{"application/zip"}, []string{".kmz"}, []int{533}},
	{"application", "vnd.hp-hpgl", "HPGL file", "HPGL", "HP Graphics Language", "", "image-x-generic", nil, nil, []string{".hpgl"}, nil},
	{"application", "vnd.hp-pcl", "PCL file", "PCL", "HP Printer Control Language", "", "image-x-generic", nil, nil, []string{".pcl"}, nil},
	{"application", "vnd.iccprofile", "ICC profile", "", "", "", "", nil, nil, []string{".icc", ".icm"}, nil},
	{"application", "vnd.kde.bluedevil-sendfile", "Service", "", "", "", "", nil, nil, nil, nil},
	{"application", "vnd.kde.fontspackage", "fonts package", "", "", "", "", nil, []string{"application/zip"}, []string{".fonts.zip"}, []int{533}},
	{"application", "vnd.kde.kcfg", "KConfigXT Configuration Options", "", "", "", "application-xml", nil, []string{"application/xml"}, []string{".kcfg"}, []int{527}},
	{"application", "vnd.kde.kcfgc", "KConfigXT Code Generation Options", "", "", "", "text-plain", nil, []string{"text/plain"}, []string{".kcfgc"}, []int{827}},
	{"application", "vnd.kde.knotificationrc", "KNotification Declaration", "", "", "", "text-plain", nil, []string{"text/plain"}, []string{".notifyrc"}, []int{827}},
	{"application", "vnd.kde.kphotoalbum-import", "KPhotoAlbum import", "", "", "", "", nil, nil, []string{".kim"}, nil},
	{"application", "vnd.kde.kxmlguirc", "KXMLGUI UI Declaration", "", "", "", "application-xml", nil, []string{"application/xml"}, []string{".rc"}, []int{527}},
	{"application", "vnd.kde.okular-archive", "Okular document archive", "", "", "", "", nil, nil, []string{".okular"}, nil},
	{"application", "vnd.lotus-1-2-3", "Lotus 1-2-3 spreadsheet", "", "", "", "x-office-spreadsheet", []string{"application/x-lotus123", "application/x-123", "application/lotus123", "application/wk1", "zz-application/zz-winassoc-123"}, nil, []string{".123", ".wk1", ".wk3", ".wk4", ".wks"}, nil},
	{"application", "vnd.lotus-wordpro", "Lotus Word Pro", "", "", "", "x-office-document", nil, nil, []string{".lwp"}, nil},
	{"application", "vnd.mozilla.xul+xml", "XUL interface document", "XUL", "XML User interface markup Language", "", "x-office-document", nil, []string{"application/xml"}, []string{".xul"}, []int{527}},
	{"application", "vnd.ms-access", "JET database", "JET", "Joint Engine Technology", "", "x-office-document", []string{"application/x-msaccess", "application/msaccess", "application/vnd.msaccess", "application/x-msaccess", "application/mdb", "application/x-mdb", "zz-application/zz-winassoc-mdb"}, nil, []string{".mdb"}, nil},
	{"application", "vnd.ms-asf", "ASF video", "ASF", "Advanced Streaming Format", "", "", []string{"video/x-ms-wm", "video/x-ms-asf", "video/x-ms-asf-plugin"}, nil, []string{".asf"}, nil},
	{"application", "vnd.ms-cab-compressed", "Microsoft Cabinet archive", "", "", "", "package-x-generic", []string{"zz-application/zz-winassoc-cab"}, nil, []string{".cab"}, nil},
	{"application", "vnd.ms-excel", "Excel spreadsheet", "", "", "", "x-office-spreadsheet", []string{"application/msexcel", "application/x-msexcel", "zz-application/zz-winassoc-xls"}, nil, []string{".xls", ".xlc", ".xll", ".xlm", ".xlw", ".xla", ".xlt", ".xld"}, nil},
	{"application", "vnd.ms-excel.addin.macroEnabled.12", "Excel add-in", "", "", "", "x-office-spreadsheet", nil, []string{"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"}, []string{".xlam"}, []int{154}},
	{"application", "vnd.ms-excel.sheet.binary.macroEnabled.12", "Excel 2007 binary spreadsheet", "", "", "", "x-office-spreadsheet", nil, []string{"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet", "application/zip"}, []string{".xlsb"}, []int{154, 533}},
	{"application", "vnd.ms-excel.sheet.macroEnabled.12", "Excel spreadsheet", "", "", "", "x-office-spreadsheet", nil, []string{"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet", "application/zip"}, []string{".xlsm"}, []int{154, 533}},
	{"application", "vnd.ms-excel.template.macroEnabled.12", "Excel spreadsheet template", "", "", "", "x-office-spreadsheet", nil, []string{"application/vnd.openxmlformats-officedocument.spreadsheetml.template", "application/zip"}, []string{".xltm"}, []int{155, 533}},
	{"application", "vnd.ms-htmlhelp", "CHM document", "CHM", "Compiled Help Modules", "", "x-office-document", []string{"application/x-chm"}, nil, []string{".chm"}, nil},
	{"application", "vnd.ms-powerpoint", "PowerPoint presentation", "", "", "", "x-office-presentation", []string{"application/powerpoint", "application/mspowerpoint", "application/x-mspowerpoint"}, nil, []string{".ppz", ".ppt", ".pps", ".pot"}, nil},
	{"application", "vnd.ms-powerpoint.addin.macroEnabled.12", "PowerPoint add-in", "", "", "", "x-office-presentation", nil, nil, []string{".ppam"}, nil},
	{"application", "vnd.ms-powerpoint.presentation.macroEnabled.12", "PowerPoint presentation", "", "", "", "x-office-presentation", nil, []string{"application/vnd.openxmlformats-officedocument.presentationml.presentation", "application/zip"}, []string{".pptm"}, []int{150, 533}},
	{"application", "vnd.ms-powerpoint.slide.macroEnabled.12", "PowerPoint slide", "", "", "", "x-office-presentation", nil, []string{"application/vnd.openxmlformats-officedocument.presentationml.slide"}, []string{".sldm"}, []int{151}},
	{"application", "vnd.ms-powerpoint.slideshow.macroEnabled.12", "PowerPoint presentation", "", "", "", "x-office-presentation", nil, []string{"application/vnd.openxmlformats-officedocument.presentationml.slideshow", "application/zip"}, []string{".ppsm"}, []int{152, 533}},
	{"application", "vnd.ms-powerpoint.template.macroEnabled.12", "PowerPoint presentation template", "", "", "", "x-office-presentation", nil, []string{"application/vnd.openxmlformats-officedocument.presentationml.template", "application/zip"}, []string{".potm"}, []int{153, 533}},
	{"application", "vnd.ms-publisher", "Microsoft Publisher document", "", "", "", "", nil, []string{"application/x-ole-storage"}, []string{".pub"}, []int{398}},
	{"application", "vnd.ms-tnef", "TNEF message", "TNEF", "Transport Neutral Encapsulation Format", "", "", []string{"application/ms-tnef"}, nil, []string{".tnef", ".tnf"}, nil},
	{"application", "vnd.ms-visio.drawing.macroEnabled.main+xml", "Office Open XML Visio Drawing", "", "", "", "image-x-generic", nil, []string{"application/zip"}, []string{".vsdm"}, []int{533}},
	{"application", "vnd.ms-visio.drawing.main+xml", "Office Open XML Visio Drawing", "", "", "", "image-x-generic", nil, []string{"application/zip"}, []string{".vsdx"}, []int{533}},
	{"application", "vnd.ms-visio.stencil.macroEnabled.main+xml", "Office Open XML Visio Stencil", "", "", "", "image-x-generic", nil, []string{"application/zip"}, []string{".vssm"}, []int{533}},
	{"application", "vnd.ms-visio.stencil.main+xml", "Office Open XML Visio Stencil", "", "", "", "image-x-generic", nil, []string{"application/zip"}, []string{".vssx"}, []int{533}},
	{"application", "vnd.ms-visio.template.macroEnabled.main+xml", "Office Open XML Visio Template", "", "", "", "image-x-generic", nil, []string{"application/zip"}, []string{".vstm"}, []int{533}},
	{"application", "vnd.ms-visio.template.main+xml", "Office Open XML Visio Template", "", "", "", "image-x-generic", nil, []string{"application/zip"}, []string{".vstx"}, []int{533}},
	{"application", "vnd.ms-word.document.macroEnabled.12", "Word document", "", "", "", "x-office-document", nil, []string{"application/vnd.openxmlformats-officedocument.wordprocessingml.document", "application/zip"}, []string{".docm"}, []int{156, 533}},
	{"application", "vnd.ms-word.template.macroEnabled.12", "Word document template", "", "", "", "x-office-document", nil, []string{"application/vnd.openxmlformats-officedocument.wordprocessingml.template", "application/zip"}, []string{".dotm"}, []int{157, 533}},
	{"application", "vnd.ms-works", "Microsoft Works document", "", "", "", "x-office-document", nil, []string{"application/x-ole-storage"}, []string{".wcm", ".wdb", ".wks", ".wps", ".xlr"}, []int{398}},
	{"application", "vnd.ms-wpl", "WPL playlist", "WPL", "Windows Media Player Playlist", "", "video-x-generic", nil, nil, []string{".wpl"}, nil},
	{"application", "vnd.nintendo.snes.rom", "Super NES ROM", "", "", "", "application-x-executable", []string{"application/x-snes-rom"}, nil, []string{".sfc", ".smc"}, nil},
	{"application", "vnd.oasis.opendocument.chart", "ODC chart", "ODC", "OpenDocument Chart", "", "x-office-spreadsheet", nil, []string{"application/zip"}, []string{".odc"}, []int{533}},
	{"application", "vnd.oasis.opendocument.chart-template", "ODC template", "ODC", "OpenDocument Chart", "", "x-office-spreadsheet", nil, []string{"application/zip"}, []string{".otc"}, []int{533}},
	{"application", "vnd.oasis.opendocument.database", "ODB database", "ODB", "OpenDocument Database", "", "x-office-document", []string{"application/vnd.sun.xml.base"}, []string{"application/zip"}, []string{".odb"}, []int{533}},
	{"application", "vnd.oasis.opendocument.formula", "ODF formula", "ODF", "OpenDocument Formula", "", "x-office-document", nil, []string{"application/zip"}, []string{".odf"}, []int{533}},
	{"application", "vnd.oasis.opendocument.formula-template", "ODF template", "ODF", "OpenDocument Formula", "", "x-office-document", nil, []string{"application/zip"}, []string{".otf"}, []int{533}},
	{"application", "vnd.oasis.opendocument.graphics", "ODG drawing", "ODG", "OpenDocument Drawing", "", "image-x-generic", nil, []string{"application/zip"}, []string{".odg"}, []int{533}},
	{"application", "vnd.oasis.opendocument.graphics-flat-xml", "ODG drawing (Flat XML)", "FODG", "OpenDocument Drawing (Flat XML)", "", "image-x-generic", nil, []string{"application/xml"}, []string{".fodg"}, []int{527}},
	{"application", "vnd.oasis.opendocument.graphics-template", "ODG template", "ODG", "OpenDocument Drawing", "", "image-x-generic", nil, []string{"application/zip"}, []string{".otg"}, []int{533}},
	{"application", "vnd.oasis.opendocument.image", "ODI image", "ODI", "OpenDocument Image", "", "image-x-generic", nil, []string{"application/zip"}, []string{".odi"}, []int{533}},
	{"application", "vnd.oasis.opendocument.presentation", "ODP presentation", "ODP", "OpenDocument Presentation", "", "x-office-presentation", nil, []string{"application/zip"}, []string{".odp"}, []int{533}},
	{"application", "vnd.oasis.opendocument.presentation-flat-xml", "ODP presentation (Flat XML)", "FODP", "OpenDocument Presentation (Flat XML)", "", "x-office-presentation", nil, []string{"application/xml"}, []string{".fodp"}, []int{527}},
	{"application", "vnd.oasis.opendocument.presentation-template", "ODP template", "ODP", "OpenDocument Presentation", "", "x-office-presentation", nil, []string{"application/zip"}, []string{".otp"}, []int{533}},
	{"application", "vnd.oasis.opendocument.spreadsheet", "ODS spreadsheet", "ODS", "OpenDocument Spreadsheet", "", "x-office-spreadsheet", nil, []string{"application/zip"}, []string{".ods"}, []int{533}},
	{"application", "vnd.oasis.opendocument.spreadsheet-flat-xml", "ODS spreadsheet (Flat XML)", "FODS", "OpenDocument Spreadsheet (Flat XML)", "", "x-office-spreadsheet", nil, []string{"application/xml"}, []string{".fods"}, []int{527}},
	{"application", "vnd.oasis.opendocument.spreadsheet-template", "ODS template", "ODS", "OpenDocument Spreadsheet", "", "x-office-spreadsheet", nil, []string{"application/zip"}, []string{".ots"}, []int{533}},
	{"application", "vnd.oasis.opendocument.text", "ODT document", "ODT", "OpenDocument Text", "", "x-office-document", nil, []string{"application/zip"}, []string{".odt"}, []int{533}},
	{"application", "vnd.oasis.opendocument.text-flat-xml", "ODT document (Flat XML)", "FODT", "OpenDocument Text (Flat XML)", "", "x-office-document", nil, []string{"application/xml"}, []string{".fodt"}, []int{527}},
	{"application", "vnd.oasis.opendocument.text-master", "ODM document", "ODM", "OpenDocument Master", "", "x-office-document", nil, []string{"application/zip"}, []string{".odm"}, []int{533}},
	{"application", "vnd.oasis.opendocument.text-master-template", "OpenDocument Master Document Template", "", "", "", "", nil, nil, []string{".otm"}, nil},
	{"application", "vnd.oasis.opendocument.text-template", "ODT template", "ODT", "OpenDocument Text", "", "x-office-document", nil, []string{"application/zip"}, []string{".ott"}, []int{533}},
	{"application", "vnd.oasis.opendocument.text-web", "OTH template", "OTH", "OpenDocument HTML", "", "text-html", nil, []string{"application/zip"}, []string{".oth"}, []int{533}},
	{"application", "vnd.openofficeorg.extension", "OpenOffice.org extension", "", "", "", "x-office-document", nil, []string{"application/zip"}, []string{".oxt"}, []int{533}},
	{"application", "vnd.openxmlformats-officedocument.presentationml.presentation", "PowerPoint 2007 presentation", "", "", "", "x-office-presentation", nil, []string{"application/zip"}, []string{".pptx"}, []int{533}},
	{"application", "vnd.openxmlformats-officedocument.presentationml.slide", "PowerPoint 2007 slide", "", "", "", "x-office-presentation", nil, []string{"application/zip"}, []string{".sldx"}, []int{533}},
	{"application", "vnd.openxmlformats-officedocument.presentationml.slideshow", "PowerPoint 2007 show", "", "", "", "x-office-presentation", nil, []string{"application/zip"}, []string{".ppsx"}, []int{533}},
	{"application", "vnd.openxmlformats-officedocument.presentationml.template", "PowerPoint 2007 presentation template", "", "", "", "x-office-presentation", nil, []string{"application/zip"}, []string{".potx"}, []int{533}},
	{"application", "vnd.openxmlformats-officedocument.spreadsheetml.sheet", "Excel 2007 spreadsheet", "", "", "", "x-office-spreadsheet", nil, []string{"application/zip"}, []string{".xlsx"}, []int{533}},
	{"application", "vnd.openxmlformats-officedocument.spreadsheetml.template", "Excel 2007 spreadsheet template", "", "", "", "x-office-spreadsheet", nil, []string{"application/zip"}, []string{".xltx"}, []int{533}},
	{"application", "vnd.openxmlformats-officedocument.wordprocessingml.document", "Word 2007 document", "", "", "", "x-office-document", nil, []string{"application/zip"}, []string{".docx"}, []int{533}},
	{"application", "vnd.openxmlformats-officedocument.wordprocessingml.template", "Word 2007 document template", "", "", "", "x-office-document", nil, []string{"application/zip"}, []string{".dotx"}, []int{533}},
	{"application", "vnd.palm", "Palm OS database", "", "", "", "", []string{"application/x-palm-database"}, nil, []string{".prc", ".pdb", ".pqa", ".oprc"}, nil},
	{"application", "vnd.rar", "RAR archive", "RAR", "Roshal ARchive", "", "package-x-generic", []string{"application/x-rar", "application/x-rar-compressed"}, nil, []string{".rar"}, nil},
	{"application", "vnd.rn-realmedia", "RealMedia document", "", "", "", "video-x-generic", []string{"application/vnd.rn-realmedia-vbr"}, nil, []string{".rm", ".rmj", ".rmm", ".rms", ".rmx", ".rmvb"}, nil},
	{"application", "vnd.snap", "Snap package", "", "", "", "", nil, []string{"application/vnd.squashfs"}, []string{".snap"}, []int{163}},
	{"application", "vnd.sqlite3", "SQLite3 database", "", "", "", "", []string{"application/x-sqlite3"}, nil, []string{".sqlite3"}, nil},
	{"application", "vnd.squashfs", "Squashfs filesystem", "", "", "", "", nil, nil, []string{".sqsh"}, nil},
	{"application", "vnd.stardivision.calc", "StarCalc spreadsheet", "", "", "", "x-office-spreadsheet", nil, nil, []string{".sdc"}, nil},
	{"application", "vnd.stardivision.chart", "StarChart chart", "", "", "", "x-office-spreadsheet", nil, nil, []string{".sds"}, nil},
	{"application", "vnd.stardivision.draw", "StarDraw drawing", "", "", "", "image-x-generic", nil, nil, []string{".sda"}, nil},
	{"application", "vnd.stardivision.impress", "StarImpress presentation", "", "", "", "x-office-presentation", nil, nil, []string{".sdd", ".sdp"}, nil},
	{"application", "vnd.stardivision.mail", "StarMail email", "", "", "", "", nil, nil, []string{".smd"}, nil},
	{"application", "vnd.stardivision.math", "StarMath formula", "", "", "", "x-office-document", nil, nil, []string{".smf"}, nil},
	{"application", "vnd.stardivision.writer", "StarWriter document", "", "", "", "x-office-document", []string{"application/vnd.stardivision.writer-global"}, nil, []string{".sdw", ".vor", ".sgl"}, nil},
	{"application", "vnd.sun.xml.calc", "OpenOffice Calc spreadsheet", "", "", "", "x-office-spreadsheet", nil, []string{"application/zip"}, []string{".sxc"}, []int{533}},
	{"application", "vnd.sun.xml.calc.template", "OpenOffice Calc template", "", "", "", "x-office-spreadsheet", nil, []string{"application/zip"}, []string{".stc"}, []int{533}},
	{"application", "vnd.sun.xml.draw", "OpenOffice Draw drawing", "", "", "", "image-x-generic", nil, []string{"application/zip"}, []string{".sxd"}, []int{533}},
	{"application", "vnd.sun.xml.draw.template", "OpenOffice Draw template", "", "", "", "image-x-generic", nil, []string{"application/zip"}, []string{".std"}, []int{533}},
	{"application", "vnd.sun.xml.impress", "OpenOffice Impress presentation", "", "", "", "x-office-presentation", nil, []string{"application/zip"}, []string{".sxi"}, []int{533}},
	{"application", "vnd.sun.xml.impress.template", "OpenOffice Impress template", "", "", "", "x-office-presentation", nil, []string{"application/zip"}, []string{".sti"}, []int{533}},
	{"application", "vnd.sun.xml.math", "OpenOffice Math formula", "", "", "", "x-office-document", nil, []string{"application/zip"}, []string{".sxm"}, []int{533}},
	{"application", "vnd.sun.xml.writer", "OpenOffice Writer document", "", "", "", "x-office-document", nil, []string{"application/zip"}, []string{".sxw"}, []int{533}},
	{"application", "vnd.sun.xml.writer.global", "OpenOffice Writer global document", "", "", "", "x-office-document", nil, []string{"application/zip"}, []string{".sxg"}, []int{533}},
	{"application", "vnd.sun.xml.writer.template", "OpenOffice Writer template", "", "", "", "x-office-document", nil, []string{"application/zip"}, []string{".stw"}, []int{533}},
	{"application", "vnd.symbian.install", "SIS package", "SIS", "Symbian Installation File", "", "package-x-generic", nil, nil, []string{".sis"}, nil},
	{"application", "vnd.tcpdump.pcap", "Network Packet Capture", "", "", "", "", []string{"application/x-pcap", "application/pcap"}, nil, []string{".pcap", ".cap", ".dmp"}, nil},
	{"application", "vnd.visio", "Microsoft Visio document", "", "", "", "x-office-document", nil, []string{"application/x-ole-storage"}, []string{".vsd", ".vst", ".vsw", ".vss"}, []int{398}},
	{"application", "vnd.wolfram.cdf", "Wolfram CDF document", "", "", "", "", nil, nil, []string{".cdf"}, nil},
	{"application", "vnd.wolfram.mathematica.package", "Wolfram Language Package", "", "", "", "", nil, nil, []string{".m"}, nil},
	{"application", "vnd.wolfram.nb", "Wolfram Notebook", "", "", "", "application-mathematica", nil, nil, []string{".nb"}, nil},
	{"application", "vnd.wolfram.wl", "Wolfram Language Package", "", "", "", "", nil, nil, []string{".wl"}, nil},
	{"application", "vnd.wordperfect", "WordPerfect document", "", "", "", "x-office-document", []string{"application/x-wordperfect", "application/wordperfect"}, nil, []string{".wp", ".wp4", ".wp5", ".wp6", ".wpd", ".wpp"}, nil},
	{"application", "vnd.youtube.yt", "YouTube Media Archive", "", "", "", "video-x-generic", nil, []string{"application/zip"}, []string{".yt"}, []int{533}},
	{"application", "winhlp", "WinHelp help file", "", "", "", "", []string{"zz-application/zz-winassoc-hlp"}, nil, []string{".hlp"}, nil},
	{"application", "x-7z-compressed", "7-zip archive", "", "", "", "package-x-generic", nil, nil, []string{".7z"}, nil},
	{"application", "x-abiword", "AbiWord document", "", "", "", "x-office-document", nil, []string{"application/xml"}, []string{".abw", ".abw.CRASHED", ".abw.gz", ".zabw"}, []int{527}},
	{"application", "x-ace", "ACE archive", "", "", "", "package-x-generic", nil, nil, []string{".ace"}, nil},
	{"application", "x-alz", "Alzip archive", "", "", "", "package-x-generic", nil, nil, []string{".alz"}, nil},
	{"application", "x-amiga-disk-format", "Amiga disk image", "", "", "", "", nil, nil, []string{".adf"}, nil},
	{"application", "x-amipro", "Lotus AmiPro document", "", "", "", "x-office-document", nil, nil, []string{".sam"}, nil},
	{"application", "x-anki", "Anki 1.2 deck", "", "", "", "", nil, nil, []string{".anki"}, nil},
	{"application", "x-apkg", "Anki 2.0 deck", "", "", "", "", nil, nil, []string{".apkg"}, nil},
	{"application", "x-aportisdoc", "AportisDoc document", "", "", "", "x-office-document", nil, []string{"application/vnd.palm"}, []string{".pdb", ".pdc"}, []int{158}},
	{"application", "x-apple-diskimage", "Apple disk image", "", "", "", "", nil, nil, []string{".dmg"}, nil},
	{"application", "x-applix-spreadsheet", "Applix Spreadsheets spreadsheet", "", "", "", "x-office-spreadsheet", nil, nil, []string{".as"}, nil},
	{"application", "x-applix-word", "Applix Words document", "", "", "", "x-office-document", nil, nil, []string{".aw"}, nil},
	{"application", "x-arc", "ARC archive", "", "", "", "package-x-generic", nil, nil, nil, nil},
	{"application", "x-archive", "AR archive", "", "", "", "package-x-generic", nil, nil, []string{".a", ".ar"}, nil},
	{"application", "x-arj", "ARJ archive", "ARJ", "Archived by Robert Jung", "", "package-x-generic", nil, nil, []string{".arj"}, nil},
	{"application", "x-asp", "ASP page", "ASP", "Active Server Page", "", "text-x-script", nil, []string{"text/plain"}, []string{".asp"}, []int{827}},
	{"application", "x-atari-2600-rom", "Atari 2600", "", "", "", "application-x-executable", nil, nil, []string{".a26"}, nil},
	{"application", "x-atari-7800-rom", "Atari 7800", "", "", "", "application-x-executable", nil, nil, []string{".a78"}, nil},
	{"application", "x-atari-lynx-rom", "Atari Lynx", "", "", "", "application-x-executable", nil, nil, []string{".lnx"}, nil},
	{"application", "x-audacity-project", "Audacity project", "", "", "", "", nil, []string{"text/xml"}, []string{".aup"}, []int{527}},
	{"application", "x-awk", "AWK script", "", "", "", "text-x-script", nil, []string{"application/x-executable", "text/plain"}, []string{".awk"}, []int{255, 827}},
	{"application", "x-bcpio", "BCPIO document", "BCPIO", "Binary CPIO", "", "package-x-generic", nil, nil, []string{".bcpio"}, nil},
	{"application", "x-bittorrent", "BitTorrent seed file", "", "", "", "", nil, nil, []string{".torrent"}, nil},
	{"application", "x-blender", "Blender scene", "", "", "", "image-x-generic", nil, nil, []string{".blender", ".blend", ".BLEND"}, nil},
	{"application", "x-bsdiff", "binary differences between files", "", "", "", "", nil, nil, []string{".bsdiff"}, nil},
	{"application", "x-bzdvi", "TeX DVI document (bzip-compressed)", "", "", "", "x-office-document", nil, []string{"application/x-bzip"}, []string{".dvi.bz2"}, []int{217}},
	{"application", "x-bzip", "Bzip archive", "", "", "", "package-x-generic", []string{"application/x-bzip2"}, nil, []string{".bz2", ".bz"}, nil},
	{"application", "x-bzip-compressed-tar", "Tar archive (bzip-compressed)", "", "", "", "package-x-generic", nil, []string{"application/x-bzip"}, []string{".tar.bz2", ".tar.bz", ".tbz2", ".tbz", ".tb2"}, []int{217}},
	{"application", "x-bzpdf", "PDF document (bzip-compressed)", "", "", "", "x-office-document", nil, []string{"application/x-bzip"}, []string{".pdf.bz2"}, []int{217}},
	{"application", "x-bzpostscript", "PostScript document (bzip-compressed)", "", "", "", "x-office-document", nil, []string{"application/x-bzip"}, []string{".ps.bz2"}, []int{217}},
	{"application", "x-cabri", "Cabri figure", "", "", "", "", nil, nil, []string{".fig"}, nil},
	{"application", "x-cb7", "comic book archive", "", "", "", "x-office-document", nil, []string{"application/x-7z-compressed"}, []string{".cb7"}, []int{191}},
	{"application", "x-cbt", "comic book archive", "", "", "", "x-office-document", nil, []string{"application/x-tar", "application/x-compressed-tar", "application/x-bzip-compressed-tar"}, []string{".cbt"}, []int{460, 233, 218}},
	{"application", "x-ccf-container", "CryptLoad Container File", "", "", "jd-container", "", nil, nil, []string{".ccf"}, nil},
	{"application", "x-ccmx", "CCMX color correction file", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".ccmx"}, []int{827}},
	{"application", "x-cd-image", "raw CD image", "", "", "", "", []string{"application/x-iso9660-image"}, []string{"application/x-raw-disk-image"}, []string{".iso", ".iso9660"}, []int{424}},
	{"application", "x-cda", "CD audio", "", "", "", "", nil, nil, []string{".cda"}, nil},
	{"application", "x-cdrdao-toc", "CD Table Of Contents", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".toc"}, []int{827}},
	{"application", "x-cisco-vpn-settings", "Cisco VPN Settings", "", "", "", "text-x-generic", nil, nil, []string{".pcf"}, nil},
	{"application", "x-class-file", "Java byte code", "", "", "", "", nil, nil, nil, nil},
	{"application", "x-cmakecache", "CMake cache file", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"application", "x-compress", "UNIX-compressed file", "", "", "", "package-x-generic", nil, nil, []string{".Z"}, nil},
	{"application", "x-compressed-tar", "Tar archive (gzip-compressed)", "", "", "", "package-x-generic", nil, []string{"application/gzip"}, []string{".tar.gz", ".tgz"}, []int{14}},
	{"application", "x-core", "program crash data", "", "", "", "", nil, nil, nil, nil},
	{"application", "x-cpio", "CPIO archive", "", "", "", "package-x-generic", nil, nil, []string{".cpio"}, nil},
	{"application", "x-cpio-compressed", "CPIO archive (gzip-compressed)", "", "", "", "package-x-generic", nil, []string{"application/gzip"}, []string{".cpio.gz"}, []int{14}},
	{"application", "x-csh", "C shell script", "", "", "", "text-x-script", nil, []string{"application/x-shellscript", "text/plain"}, []string{".csh"}, []int{440, 827}},
	{"application", "x-cue", "CD image cuesheet", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".cue"}, []int{827}},
	{"application", "x-dar", "DAR archive", "", "", "", "package-x-generic", nil, nil, []string{".dar"}, nil},
	{"application", "x-dbf", "Xbase document", "", "", "", "x-office-document", []string{"application/x-dbase", "application/dbf", "application/dbase"}, nil, []string{".dbf"}, nil},
	{"application", "x-dc-rom", "Dreamcast GD-ROM", "", "", "", "application-x-executable", nil, nil, []string{".dc"}, nil},
	{"application", "x-designer", "Qt Designer file", "", "", "", "x-office-document", nil, []string{"application/xml"}, []string{".ui"}, []int{527}},
	{"application", "x-desktop", "desktop configuration file", "", "", "", "text-x-generic", []string{"application/x-gnome-app-info"}, []string{"text/plain"}, []string{".desktop", ".kdelnk"}, []int{827}},
	{"application", "x-dia-diagram", "Dia diagram", "", "", "", "image-x-generic", nil, []string{"application/xml"}, []string{".dia"}, []int{527}},
	{"application", "x-dia-shape", "Dia shape", "", "", "", "image-x-generic", nil, []string{"application/xml"}, []string{".shape"}, []int{527}},
	{"application", "x-dlc-container", "Download Link Container File", "", "", "jd-container", "", nil, nil, []string{".dlc"}, nil},
	{"application", "x-docbook+xml", "DocBook document", "", "", "", "x-office-document", []string{"application/docbook+xml", "application/vnd.oasis.docbook+xml"}, []string{"application/xml"}, []string{".dbk", ".docbook"}, []int{527}},
	{"application", "x-doom-wad", "Doom WAD", "WAD", "Where's All the Data", "", "package-x-generic", nil, nil, []string{".wad"}, nil},
	{"application", "x-drgeo", "Dr. Geo figure", "", "", "", "", nil, nil, []string{".fgeo"}, nil},
	{"application", "x-dvi", "TeX DVI document", "DVI", "Device independent file format", "", "x-office-document", nil, nil, []string{".dvi"}, nil},
	{"application", "x-e-theme", "Enlightenment theme", "", "", "", "", nil, nil, []string{".etheme"}, nil},
	{"application", "x-egon", "Egon Animator animation", "", "", "", "image-x-generic", nil, nil, []string{".egon"}, nil},
	{"application", "x-esri-shape", "ESRI Shapefile", "", "", "", "application-vnd-google-earth-kml", nil, nil, []string{".shp"}, nil},
	{"application", "x-esri-shape-index", "ESRI Shapefile Index", "", "", "", "application-octet-stream", nil, nil, []string{".shx"}, nil},
	{"application", "x-executable", "executable", "", "", "", "application-x-executable", nil, nil, nil, nil},
	{"application", "x-fds-disk", "Nintendo FDS disk image", "FDS", "Famicom Disk System", "", "", nil, nil, []string{".fds"}, nil},
	{"application", "x-fictionbook+xml", "FictionBook document", "", "", "", "", []string{"application/x-fictionbook"}, []string{"application/xml"}, []string{".fb2"}, []int{527}},
	{"application", "x-fluid", "FLTK Fluid file", "FLTK", "Fast Light Toolkit", "", "x-office-document", nil, []string{"text/plain"}, []string{".fl"}, []int{827}},
	{"application", "x-font-afm", "Adobe font metrics", "", "", "", "font-x-generic", nil, nil, []string{".afm"}, nil},
	{"application", "x-font-bdf", "BDF font", "", "", "", "font-x-generic", nil, nil, []string{".bdf"}, nil},
	{"application", "x-font-dos", "DOS font", "", "", "", "font-x-generic", nil, nil, nil, nil},
	{"application", "x-font-framemaker", "Adobe FrameMaker font", "", "", "", "font-x-generic", nil, nil, nil, nil},
	{"application", "x-font-libgrx", "LIBGRX font", "", "", "", "font-x-generic", nil, nil, nil, nil},
	{"application", "x-font-linux-psf", "Linux PSF console font", "", "", "", "font-x-generic", nil, nil, []string{".psf"}, nil},
	{"application", "x-font-pcf", "PCF font", "", "", "", "font-x-generic", nil, nil, []string{".pcf", ".pcf.Z", ".pcf.gz"}, nil},
	{"application", "x-font-snf", "SNF bitmap font", "", "", "", "", nil, nil, []string{".snf", ".snf.Z", ".snf.gz"}, nil},
	{"application", "x-font-speedo", "Speedo font", "", "", "", "font-x-generic", nil, nil, []string{".spd"}, nil},
	{"application", "x-font-sunos-news", "SunOS News font", "", "", "", "font-x-generic", nil, nil, nil, nil},
	{"application", "x-font-tex", "TeX font", "", "", "", "font-x-generic", nil, nil, nil, nil},
	{"application", "x-font-tex-tfm", "TeX font metrics", "", "", "", "font-x-generic", nil, nil, nil, nil},
	{"application", "x-font-ttx", "TrueType XML font", "", "", "", "font-x-generic", nil, []string{"application/xml"}, []string{".ttx"}, []int{527}},
	{"application", "x-font-type1", "PostScript type-1 font", "", "", "", "font-x-generic", nil, []string{"application/postscript"}, []string{".pfa", ".pfb", ".gsf"}, []int{54}},
	{"application", "x-font-vfont", "V font", "", "", "", "font-x-generic", nil, nil, nil, nil},
	{"application", "x-gameboy-color-rom", "Game Boy Color ROM", "", "", "", "application-x-executable", nil, nil, []string{".gbc", ".cgb"}, nil},
	{"application", "x-gameboy-rom", "Game Boy ROM", "", "", "", "application-x-executable", nil, nil, []string{".gb", ".sgb"}, nil},
	{"application", "x-gamecube-rom", "GameCube disc image", "", "", "", "application-x-executable", []string{"application/x-gamecube-iso-image"}, nil, []string{".iso"}, nil},
	{"application", "x-gamegear-rom", "Game Gear ROM", "", "", "", "application-x-executable", nil, nil, []string{".gg"}, nil},
	{"application", "x-gba-rom", "Game Boy Advance ROM", "", "", "", "application-x-executable", nil, nil, []string{".gba", ".agb"}, nil},
	{"application", "x-gdbm", "GDBM database", "GDBM", "GNU Database Manager", "", "", nil, nil, nil, nil},
	{"application", "x-gedcom", "GEDCOM family history", "GEDCOM", "GEnealogical Data COMmunication", "", "x-office-document", []string{"text/gedcom"}, nil, []string{".ged", ".gedcom"}, nil},
	{"application", "x-genesis-32x-rom", "Genesis 32X ROM", "", "", "", "application-x-executable", nil, nil, []string{".32x", ".mdx"}, nil},
	{"application", "x-genesis-rom", "Genesis ROM", "", "", "", "application-x-executable", nil, nil, []string{".gen", ".smd"}, nil},
	{"application", "x-gettext-translation", "translated messages (machine-readable)", "", "", "", "", nil, nil, []string{".gmo", ".mo"}, nil},
	{"application", "x-glade", "Glade project", "", "", "", "x-office-document", nil, []string{"application/xml"}, []string{".glade"}, []int{527}},
	{"application", "x-gnucash", "GnuCash financial data", "", "", "", "x-office-spreadsheet", nil, nil, []string{".gnucash", ".gnc", ".xac"}, nil},
	{"application", "x-gnumeric", "Gnumeric spreadsheet", "", "", "", "x-office-spreadsheet", nil, nil, []string{".gnumeric"}, nil},
	{"application", "x-gnuplot", "Gnuplot document", "", "", "", "x-office-document", nil, []string{"text/plain"}, []string{".gp", ".gplt", ".gnuplot"}, []int{827}},
	{"application", "x-go-sgf", "SGF record", "SGF", "Smart Game Format", "", "text-x-generic", nil, []string{"text/plain"}, []string{".sgf"}, []int{827}},
	{"application", "x-graphite", "Graphite scientific graph", "", "", "", "x-office-document", nil, nil, []string{".gra"}, nil},
	{"application", "x-gtk-builder", "GTK+ Builder", "", "", "", "x-office-document", nil, []string{"application/xml"}, []string{".ui"}, []int{527}},
	{"application", "x-gtktalog", "GTKtalog catalog", "", "", "", "x-office-document", nil, nil, nil, nil},
	{"application", "x-gz-font-linux-psf", "Linux PSF console font (gzip-compressed)", "", "", "", "font-x-generic", nil, []string{"application/gzip"}, []string{".psf.gz"}, []int{14}},
	{"application", "x-gzdvi", "TeX DVI document (gzip-compressed)", "", "", "", "x-office-document", nil, []string{"application/gzip"}, []string{".dvi.gz"}, []int{14}},
	{"application", "x-gzpdf", "PDF document (gzip-compressed)", "", "", "", "x-office-document", nil, []string{"application/gzip"}, []string{".pdf.gz"}, []int{14}},
	{"application", "x-gzpostscript", "PostScript document (gzip-compressed)", "", "", "", "x-office-document", nil, []string{"application/gzip"}, []string{".ps.gz"}, []int{14}},
	{"application", "x-hdf", "HDF document", "HDF", "Hierarchical Data Format", "", "x-office-document", nil, nil, []string{".hdf", ".hdf4", ".h4", ".hdf5", ".h5"}, nil},
	{"application", "x-hfe-floppy-image", "HFE floppy disk image", "HFE", "HxC Floppy Emulator", "", "application-x-executable", []string{"application/x-hfe-file"}, nil, []string{".hfe"}, nil},
	{"application", "x-hwp", "Haansoft Hangul document", "", "", "", "x-office-document", []string{"application/vnd.haansoft-hwp"}, nil, []string{".hwp"}, nil},
	{"application", "x-hwt", "Haansoft Hangul document template", "", "", "", "x-office-document", []string{"application/vnd.haansoft-hwt"}, nil, []string{".hwt"}, nil},
	{"application", "x-ica", "Citrix ICA settings file", "ICA", "Independent Computing Architecture", "", "text-x-generic", nil, []string{"text/plain"}, []string{".ica"}, []int{827}},
	{"application", "x-icq", "ICQ contact", "", "", "", "", nil, nil, []string{".uin", ".icq"}, nil},
	{"application", "x-iff", "IFF file", "IFF", "Interchange File Format", "", "", nil, nil, nil, nil},
	{"application", "x-ipod-firmware", "iPod firmware", "", "", "", "", nil, nil, nil, nil},
	{"application", "x-ipynb+json", "Jupyter Notebook", "", "", "", "x-office-document", nil, []string{"application/json"}, []string{".ipynb"}, []int{18}},
	{"application", "x-iso9660-appimage", "AppImage application bundle", "", "", "", "application-x-executable", nil, []string{"application/x-executable", "application/x-iso9660-image"}, []string{".appimage"}, []int{255, 226}},
	{"application", "x-it87", "IT 8.7 color calibration file", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".it87"}, []int{827}},
	{"application", "x-iwork-keynote-sffkey", "Apple Keynote 5 presentation", "", "", "", "x-office-presentation", []string{"application/vnd.apple.keynote"}, []string{"application/zip"}, []string{".key"}, []int{533}},
	{"application", "x-java", "Java class", "", "", "", "", []string{"application/java", "application/java-byte-code", "application/java-vm", "application/x-java-class", "application/x-java-vm"}, nil, []string{".class"}, nil},
	{"application", "x-java-applet", "Java applet", "", "", "", "", nil, nil, nil, nil},
	{"application", "x-java-archive", "Java archive", "", "", "", "package-x-generic", []string{"application/x-jar", "application/java-archive"}, []string{"application/zip"}, []string{".jar"}, []int{533}},
	{"application", "x-java-jce-keystore", "Java JCE keystore", "JCE", "Java Cryptography Extension", "", "", nil, nil, []string{".jceks"}, nil},
	{"application", "x-java-jnlp-file", "JNLP file", "JNLP", "Java Network Launching Protocol", "", "text-x-script", nil, []string{"application/xml"}, []string{".jnlp"}, []int{527}},
	{"application", "x-java-keystore", "Java keystore", "", "", "", "", nil, nil, []string{".jks", ".ks"}, nil},
	{"application", "x-java-pack200", "Pack200 Java archive", "", "", "", "package-x-generic", nil, nil, []string{".pack"}, nil},
	{"application", "x-jbuilder-project", "JBuilder project", "", "", "", "x-office-document", nil, nil, []string{".jpr", ".jpx"}, nil},
	{"application", "x-k3b", "K3b project", "", "", "", "", nil, []string{"application/zip"}, []string{".k3b"}, []int{533}},
	{"application", "x-karbon", "Karbon14 drawing", "", "", "", "image-x-generic", nil, nil, []string{".karbon"}, nil},
	{"application", "x-kcachegrind", "Cachegrind/Callgrind profile dump", "", "", "", "", nil, nil, nil, nil},
	{"application", "x-kchart", "KChart chart", "", "", "", "x-office-spreadsheet", nil, nil, []string{".chrt"}, nil},
	{"application", "x-kcsrc", "KDE color scheme", "KDE", "K Desktop Environment", "", "", nil, nil, []string{".kcsrc"}, nil},
	{"application", "x-kdenlive", "Kdenlive video project document", "", "", "", "", nil, []string{"video/mlt-playlist"}, []string{".kdenlive"}, []int{958}},
	{"application", "x-kdenlivetitle", "Kdenlive video title", "", "", "", "", nil, []string{"application/xml"}, []string{".kdenlivetitle"}, []int{527}},
	{"application", "x-kexi-connectiondata", "Kexi settings for database server connection", "", "", "", "", nil, nil, []string{".kexic"}, nil},
	{"application", "x-kexiproject-shortcut", "shortcut to Kexi project on database server", "", "", "", "", nil, nil, []string{".kexis"}, nil},
	{"application", "x-kexiproject-sqlite2", "Kexi database file-based project", "", "", "", "", nil, []string{"application/x-sqlite2"}, []string{".kexi"}, []int{453}},
	{"application", "x-kexiproject-sqlite3", "Kexi database file-based project", "", "", "", "", []string{"application/x-vnd.kde.kexi", "application/x-kexiproject-sqlite"}, []string{"application/x-sqlite3"}, []string{".kexi"}, []int{162}},
	{"application", "x-kformula", "KFormula formula", "", "", "", "x-office-document", nil, nil, []string{".kfo"}, nil},
	{"application", "x-kgeo", "KGeo figure", "", "", "", "", nil, nil, []string{".kgeo"}, nil},
	{"application", "x-kgetlist", "KGet download list", "", "", "", "", nil, []string{"application/xml"}, []string{".kgt"}, []int{527}},
	{"application", "x-khtml-adaptor", "KHTML Extension Adaptor", "", "", "", "", nil, nil, nil, nil},
	{"application", "x-kig", "Kig figure", "", "", "", "", nil, nil, []string{".kig", ".kigz"}, nil},
	{"application", "x-killustrator", "KIllustrator drawing", "", "", "", "image-x-generic", nil, nil, []string{".kil"}, nil},
	{"application", "x-kivio", "Kivio flowchart", "", "", "", "x-office-document", nil, nil, []string{".flw"}, nil},
	{"application", "x-kmplot", "KmPlot file", "", "", "", "", nil, nil, []string{".fkt"}, nil},
	{"application", "x-kns", "KNewStuff package", "", "", "", "", nil, []string{"application/zip"}, []string{".kns"}, []int{533}},
	{"application", "x-kolf", "Kolf saved game", "", "", "", "", nil, nil, []string{".kolfgame"}, nil},
	{"application", "x-kommander", "Kommander file", "", "", "", "", nil, []string{"text/plain"}, []string{".kmdr"}, []int{827}},
	{"application", "x-kontour", "Kontour drawing", "", "", "", "image-x-generic", nil, nil, []string{".kon"}, nil},
	{"application", "x-kopete-emoticons", "Kopete emoticons archive", "", "", "", "", nil, nil, []string{".kopete-emoticons"}, nil},
	{"application", "x-kourse", "Kolf course", "", "", "", "", nil, nil, []string{".kolf", ".course", ".kourse"}, nil},
	{"application", "x-kpovmodeler", "KPovModeler scene", "", "", "", "image-x-generic", nil, nil, []string{".kpm"}, nil},
	{"application", "x-kpresenter", "KPresenter presentation", "", "", "", "x-office-presentation", nil, nil, []string{".kpr", ".kpt"}, nil},
	{"application", "x-krita", "Krita document", "", "", "", "x-office-document", nil, nil, []string{".kra"}, nil},
	{"application", "x-kseg", "KSeg document", "", "", "", "", nil, nil, []string{".seg"}, nil},
	{"application", "x-kspread", "KSpread spreadsheet", "", "", "", "x-office-spreadsheet", nil, nil, []string{".ksp"}, nil},
	{"application", "x-kspread-crypt", "KSpread spreadsheet (encrypted)", "", "", "", "x-office-spreadsheet", nil, nil, nil, nil},
	{"application", "x-ksysguard", "KDE system monitor", "", "", "", "", nil, nil, []string{".sgrd"}, nil},
	{"application", "x-ksysv-package", "KSysV init package", "", "", "", "package-x-generic", nil, nil, nil, nil},
	{"application", "x-ktheme", "KDE theme", "", "", "", "", nil, []string{"application/zip"}, []string{".kth"}, []int{533}},
	{"application", "x-kudesigner", "Kugar report template", "", "", "", "", nil, nil, []string{".kut"}, nil},
	{"application", "x-kugar", "Kugar document", "", "", "", "x-office-document", nil, nil, []string{".kud"}, nil},
	{"application", "x-kvtml", "vocabulary trainer document", "", "", "", "", nil, []string{"application/xml"}, []string{".kvtml"}, []int{527}},
	{"application", "x-kwallet", "KWallet wallet", "", "", "", "", nil, nil, []string{".kwl"}, nil},
	{"application", "x-kword", "KWord document", "", "", "", "x-office-document", nil, nil, []string{".kwd", ".kwt"}, nil},
	{"application", "x-kword-crypt", "KWord document (encrypted)", "", "", "", "x-office-document", nil, nil, nil, nil},
	{"application", "x-kwordquiz", "KWordQuiz vocabulary", "", "", "", "", nil, nil, []string{".wql"}, nil},
	{"application", "x-lha", "LHA archive", "", "", "", "package-x-generic", []string{"application/x-lzh-compressed"}, nil, []string{".lha", ".lzh"}, nil},
	{"application", "x-lhz", "LHZ archive", "", "", "", "package-x-generic", nil, nil, []string{".lhz"}, nil},
	{"application", "x-lrzip", "Lrzip archive", "", "", "", "package-x-generic", nil, nil, []string{".lrz"}, nil},
	{"application", "x-lrzip-compressed-tar", "Tar archive (lrzip-compressed)", "", "", "", "package-x-generic", nil, []string{"application/x-lrzip"}, []string{".tar.lrz", ".tlrz"}, []int{359}},
	{"application", "x-lyx", "LyX document", "", "", "", "x-office-document", []string{"text/x-lyx"}, []string{"text/plain"}, []string{".lyx"}, []int{827}},
	{"application", "x-lz4", "LZ4 archive", "", "", "", "package-x-generic", nil, nil, []string{".lz4"}, nil},
	{"application", "x-lz4-compressed-tar", "Tar archive (LZ4-compressed)", "", "", "", "package-x-generic", nil, []string{"application/x-lz4"}, []string{".tar.lz4"}, []int{362}},
	{"application", "x-lzip", "Lzip archive", "", "", "", "package-x-generic", nil, nil, []string{".lz"}, nil},
	{"application", "x-lzip-compressed-tar", "Tar archive (lzip-compressed)", "", "", "", "package-x-generic", nil, []string{"application/x-lzip"}, []string{".tar.lz"}, []int{364}},
	{"application", "x-lzma", "LZMA archive", "LZMA", "Lempel-Ziv-Markov chain-Algorithm", "", "package-x-generic", nil, nil, []string{".lzma"}, nil},
	{"application", "x-lzma-compressed-tar", "Tar archive (LZMA-compressed)", "", "", "", "package-x-generic", nil, []string{"application/x-lzma"}, []string{".tar.lzma", ".tlz"}, []int{366}},
	{"application", "x-lzop", "LZO archive", "LZO", "Lempel-Ziv-Oberhumer", "", "package-x-generic", nil, nil, []string{".lzo"}, nil},
	{"application", "x-lzpdf", "PDF document (lzip-compressed)", "", "", "", "x-office-document", nil, []string{"application/x-lzip"}, []string{".pdf.lz"}, []int{364}},
	{"application", "x-m4", "M4 macro", "", "", "", "text-x-script", nil, []string{"text/plain"}, []string{".m4"}, []int{827}},
	{"application", "x-macbinary", "Macintosh MacBinary file", "", "", "", "package-x-generic", nil, nil, nil, nil},
	{"application", "x-magicpoint", "MagicPoint presentation", "", "", "", "x-office-presentation", nil, []string{"text/plain"}, []string{".mgp"}, []int{827}},
	{"application", "x-markaby", "Markaby script", "", "", "", "text-x-script", nil, []string{"application/x-ruby"}, []string{".mab"}, []int{430}},
	{"application", "x-matroska", "Matroska stream", "", "", "", "video-x-generic", nil, nil, nil, nil},
	{"application", "x-mif", "Adobe FrameMaker MIF document", "", "", "", "", nil, nil, []string{".mif"}, nil},
	{"application", "x-mimearchive", "MHTML web archive", "MHTML", "MIME HTML", "", "", nil, []string{"multipart/related"}, []string{".mhtml", ".mht"}, []int{814}},
	{"application", "x-mkvtoolnix-gui-settings", "MKVToolNix GUI settings", "", "", "", "", nil, []string{"text/plain"}, []string{".mtxcfg"}, []int{827}},
	{"application", "x-mobipocket-ebook", "Mobipocket e-book", "", "", "", "x-office-document", nil, []string{"application/vnd.palm", "application/x-palm-database"}, []string{".mobi", ".prc"}, []int{158}},
	{"application", "x-mozilla-bookmarks", "Mozilla bookmarks", "", "", "", "text-html", []string{"application/x-netscape-bookmarks"}, []string{"text/html"}, nil, []int{824}},
	{"application", "x-ms-dos-executable", "DOS/Windows executable", "", "", "", "application-x-executable", nil, nil, []string{".exe"}, nil},
	{"application", "x-ms-shortcut", "Windows link", "", "", "", "", []string{"application/x-win-lnk"}, nil, []string{".lnk"}, nil},
	{"application", "x-ms-wim", "WIM disk Image", "WIM", "Windows Imaging Format", "", "", nil, nil, []string{".wim", ".swm"}, nil},
	{"application", "x-msi", "Windows Installer package", "", "", "", "", nil, []string{"application/x-ole-storage"}, []string{".msi"}, []int{398}},
	{"application", "x-mswinurl", "Internet shortcut", "", "", "", "", nil, nil, []string{".url"}, nil},
	{"application", "x-mswrite", "WRI document", "", "", "", "x-office-document", nil, nil, []string{".wri"}, nil},
	{"application", "x-msx-rom", "MSX ROM", "", "", "", "application-x-executable", nil, nil, []string{".msx"}, nil},
	{"application", "x-n64-rom", "Nintendo64 ROM", "", "", "", "application-x-executable", nil, nil, []string{".n64", ".z64", ".v64"}, nil},
	{"application", "x-nautilus-link", "Nautilus link", "", "", "", "text-x-generic", nil, []string{"text/plain"}, nil, []int{827}},
	{"application", "x-navi-animation", "Windows animated cursor", "", "", "", "", nil, nil, []string{".ani"}, nil},
	{"application", "x-neo-geo-pocket-color-rom", "Neo-Geo Pocket Color ROM", "", "", "", "application-x-executable", nil, nil, []string{".ngc"}, nil},
	{"application", "x-neo-geo-pocket-rom", "Neo-Geo Pocket ROM", "", "", "", "application-x-executable", nil, nil, []string{".ngp"}, nil},
	{"application", "x-nes-rom", "NES ROM", "", "", "", "application-x-executable", nil, nil, []string{".nes", ".nez", ".unf", ".unif"}, nil},
	{"application", "x-netcdf", "Unidata NetCDF document", "NetCDF", "Network Common Data Form", "", "x-office-document", nil, nil, []string{".cdf", ".nc"}, nil},
	{"application", "x-netshow-channel", "Windows Media Station file", "", "", "", "video-x-generic", nil, []string{"application/vnd.ms-asf"}, []string{".nsc"}, []int{101}},
	{"application", "x-nintendo-ds-rom", "Nintendo DS ROM", "", "", "", "application-x-executable", nil, nil, []string{".nds"}, nil},
	{"application", "x-nzb", "NewzBin usenet index", "", "", "", "", nil, []string{"application/xml"}, []string{".nzb"}, []int{527}},
	{"application", "x-object", "object code", "", "", "", "x-office-document", nil, nil, []string{".o"}, nil},
	{"application", "x-ole-storage", "OLE2 compound document storage", "", "", "", "x-office-document", nil, nil, nil, nil},
	{"application", "x-oleo", "GNU Oleo spreadsheet", "", "", "", "x-office-spreadsheet", nil, nil, []string{".oleo"}, nil},
	{"application", "x-osm+xml", "OSM Data", "OSM", "OpenStreetMap", "", "application-vnd-google-earth-kml", nil, []string{"application/xml"}, []string{".osm", ".osc"}, []int{527}},
	{"application", "x-pagemaker", "Adobe PageMaker", "", "", "", "x-office-document", nil, []string{"application/x-ole-storage"}, []string{".p65", ".pm", ".pm6", ".pmd"}, []int{398}},
	{"application", "x-pak", "PAK archive", "", "", "", "package-x-generic", nil, nil, []string{".pak"}, nil},
	{"application", "x-par2", "Parchive archive", "Parchive", "Parity Volume Set Archive", "", "package-x-generic", nil, nil, []string{".PAR2", ".par2"}, nil},
	{"application", "x-partial-download", "Partially downloaded file", "", "", "", "package-x-generic", nil, nil, []string{".wkdownload", ".crdownload", ".part"}, nil},
	{"application", "x-pc-engine-rom", "PC Engine ROM", "", "", "", "application-x-executable", nil, nil, []string{".pce"}, nil},
	{"application", "x-pef-executable", "PEF executable", "", "", "", "application-x-executable", nil, nil, nil, nil},
	{"application", "x-pem-file", "Openssl PEM format", "PEM", "", "", "", nil, []string{"text/plain"}, []string{".pem"}, []int{827}},
	{"application", "x-pem-key", "Private Key in PEM format", "", "", "", "", nil, []string{"application/x-pem-file"}, nil, []int{407}},
	{"application", "x-perl", "Perl script", "", "", "", "text-x-script", []string{"text/x-perl"}, []string{"application/x-executable", "text/plain"}, []string{".pl", ".PL", ".pm", ".al", ".perl", ".pod", ".t"}, []int{255, 827}},
	{"application", "x-php", "PHP script", "", "", "", "text-x-script", nil, []string{"text/plain"}, []string{".php", ".php3", ".php4", ".php5", ".phps"}, []int{827}},
	{"application", "x-pkcs7-certificates", "PKCS#7 certificate bundle", "PKCS", "Public-Key Cryptography Standards", "", "", nil, nil, []string{".p7b", ".spc"}, nil},
	{"application", "x-planperfect", "PlanPerfect spreadsheet", "", "", "", "x-office-spreadsheet", nil, nil, []string{".pln"}, nil},
	{"application", "x-plasma", "plasmoid", "", "", "", "", nil, []string{"application/zip"}, []string{".plasmoid"}, []int{533}},
	{"application", "x-pocket-word", "Pocket Word document", "", "", "", "x-office-document", nil, nil, []string{".psw"}, nil},
	{"application", "x-profile", "profiler results", "", "", "", "text-x-generic", nil, []string{"text/plain"}, nil, []int{827}},
	{"application", "x-pw", "Pathetic Writer document", "", "", "", "x-office-document", nil, nil, []string{".pw"}, nil},
	{"application", "x-python-bytecode", "Python bytecode", "", "", "", "", nil, nil, []string{".pyc", ".pyo"}, nil},
	{"application", "x-qpress", "Qpress archive", "", "", "", "package-x-generic", nil, nil, []string{".qp"}, nil},
	{"application", "x-qtiplot", "QtiPlot document", "", "", "", "x-office-document", nil, []string{"text/plain"}, []string{".qti", ".qti.gz"}, []int{827}},
	{"application", "x-quanta", "Quanta project", "", "", "", "", nil, []string{"text/plain"}, []string{".quanta"}, []int{827}},
	{"application", "x-quattropro", "Quattro Pro spreadsheet", "", "", "", "x-office-spreadsheet", nil, nil, []string{".wb1", ".wb2", ".wb3"}, nil},
	{"application", "x-quicktime-media-link", "QuickTime metalink playlist", "", "", "", "video-x-generic", []string{"application/x-quicktimeplayer"}, []string{"video/quicktime"}, []string{".qtl"}, []int{963}},
	{"application", "x-qw", "Quicken document", "", "", "", "x-office-spreadsheet", nil, nil, []string{".qif"}, nil},
	{"application", "x-raw-disk-image", "Raw disk image", "", "", "", "", nil, nil, []string{".raw-disk-image", ".img"}, nil},
	{"application", "x-raw-disk-image-xz-compressed", "Raw disk image (XZ-compressed)", "", "", "", "", nil, []string{"application/x-xz"}, []string{".raw-disk-image.xz", ".img.xz"}, []int{518}},
	{"application", "x-raw-floppy-disk-image", "Floppy disk image", "", "", "", "", []string{"application/x-fd-file"}, []string{"application/x-raw-disk-image"}, []string{".fd", ".qd"}, []int{424}},
	{"application", "x-riff", "RIFF container", "", "", "", "", nil, nil, nil, nil},
	{"application", "x-rpm", "RPM package", "", "", "", "package-x-generic", []string{"application/x-redhat-package-manager"}, nil, []string{".rpm"}, nil},
	{"application", "x-rsdf-container", "RapidShare Download File", "", "", "jd-container", "", nil, nil, []string{".rsdf"}, nil},
	{"application", "x-ruby", "Ruby script", "", "", "", "text-x-script", nil, []string{"application/x-executable", "text/plain"}, []string{".rb"}, []int{255, 827}},
	{"application", "x-sami", "SAMI subtitles", "SAMI", "Synchronized Accessible Media Interchange", "", "text-x-generic", nil, []string{"text/plain"}, []string{".smi", ".sami"}, []int{827}},
	{"application", "x-saturn-rom", "Sega Saturn disc image", "", "", "", "application-x-executable", nil, nil, []string{".bin", ".iso"}, nil},
	{"application", "x-sc", "SC/Xspread spreadsheet", "", "", "", "x-office-spreadsheet", nil, nil, nil, nil},
	{"application", "x-sega-cd-rom", "Sega CD disc image", "", "", "", "application-x-executable", nil, nil, []string{".bin", ".iso"}, nil},
	{"application", "x-sega-pico-rom", "Sega Pico ROM", "", "", "", "application-x-executable", nil, nil, nil, nil},
	{"application", "x-sg1000-rom", "SG-1000 ROM", "", "", "", "application-x-executable", nil, nil, []string{".sg"}, nil},
	{"application", "x-shar", "shell archive", "", "", "", "package-x-generic", nil, nil, []string{".shar"}, nil},
	{"application", "x-shared-library-la", "libtool shared library", "", "", "", "text-x-script", nil, []string{"text/plain"}, []string{".la"}, []int{827}},
	{"application", "x-sharedlib", "shared library", "", "", "", "", nil, nil, []string{".so"}, nil},
	{"application", "x-shellscript", "shell script", "", "", "", "text-x-script", []string{"text/x-sh"}, []string{"application/x-executable", "text/plain"}, []string{".sh"}, []int{255, 827}},
	{"application", "x-shorten", "Shorten audio", "", "", "", "audio-x-generic", []string{"audio/x-shorten"}, nil, []string{".shn"}, nil},
	{"application", "x-siag", "Siag spreadsheet", "", "", "", "x-office-spreadsheet", nil, nil, []string{".siag"}, nil},
	{"application", "x-slp", "Stampede package", "", "", "", "package-x-generic", nil, nil, nil, nil},
	{"application", "x-smaf", "SMAF audio", "SMAF", "Synthetic music Mobile Application Format", "", "audio-x-generic", []string{"application/vnd.smaf"}, nil, []string{".mmf", ".smaf"}, nil},
	{"application", "x-smb-server", "Windows server", "", "", "", "", nil, []string{"inode/directory"}, nil, []int{698}},
	{"application", "x-smb-workgroup", "Windows workgroup", "", "", "", "", nil, []string{"inode/directory"}, nil, []int{698}},
	{"application", "x-sms-rom", "Master System ROM", "", "", "", "application-x-executable", nil, nil, []string{".sms"}, nil},
	{"application", "x-source-rpm", "Source RPM package", "", "", "", "package-x-generic", nil, []string{"application/x-rpm"}, []string{".src.rpm", ".spm"}, []int{428}},
	{"application", "x-spkac", "SPKAC Certificate Request", "", "", "", "", nil, nil, []string{".spkac"}, nil},
	{"application", "x-spkac+base64", "SPKAC Certificate Request in OpenSSL format", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"application", "x-spss-por", "SPSS Portable Data File", "", "", "", "", nil, nil, []string{".por"}, nil},
	{"application", "x-spss-sav", "SPSS Data File", "", "", "", "", []string{"application/x-spss-savefile"}, nil, []string{".sav", ".zsav"}, nil},
	{"application", "x-sqlite2", "SQLite2 database", "", "", "", "", nil, nil, []string{".sqlite2"}, nil},
	{"application", "x-stuffit", "StuffIt archive", "", "", "", "package-x-generic", []string{"application/stuffit", "application/x-sit"}, nil, []string{".sit"}, nil},
	{"application", "x-subrip", "SubRip subtitles", "", "", "", "text-x-generic", []string{"application/x-srt"}, []string{"text/plain"}, []string{".srt"}, []int{827}},
	{"application", "x-superkaramba", "SuperKaramba theme", "", "", "", "", nil, []string{"application/zip"}, []string{".skz"}, []int{533}},
	{"application", "x-sv4cpio", "SV4 CPIO archive", "", "", "", "package-x-generic", nil, nil, []string{".sv4cpio"}, nil},
	{"application", "x-sv4crc", "SV4 CPIO archive (with CRC)", "", "", "", "package-x-generic", nil, nil, []string{".sv4crc"}, nil},
	{"application", "x-t602", "T602 document", "", "", "", "x-office-document", nil, nil, []string{".602"}, nil},
	{"application", "x-tar", "Tar archive", "", "", "", "package-x-generic", []string{"application/x-gtar"}, nil, []string{".tar", ".gtar", ".gem"}, nil},
	{"application", "x-tarz", "Tar archive (compressed)", "", "", "", "package-x-generic", nil, []string{"application/x-compress"}, []string{".tar.Z", ".taz"}, []int{232}},
	{"application", "x-tex-gf", "generic font file", "", "", "", "font-x-generic", nil, nil, []string{".gf"}, nil},
	{"application", "x-tex-pk", "packed font file", "", "", "", "font-x-generic", nil, nil, []string{".pk"}, nil},
	{"application", "x-tgif", "TGIF document", "", "", "", "x-office-document", nil, nil, []string{".obj"}, nil},
	{"application", "x-theme", "theme", "", "", "", "package-x-generic", nil, []string{"application/x-desktop"}, []string{".theme"}, []int{243}},
	{"application", "x-thomson-cartridge-memo7", "Thomson Mémo7 cartridge", "", "", "", "application-x-executable", nil, nil, []string{".m7"}, nil},
	{"application", "x-thomson-cassette", "Thomson cassette", "", "", "", "application-x-executable", nil, nil, []string{".k7"}, nil},
	{"application", "x-thomson-sap-image", "SAP Thomson floppy disk image", "SAP", "Système d'Archivage Pukall", "", "application-x-executable", []string{"application/x-sap-file"}, nil, []string{".sap"}, nil},
	{"application", "x-toutdoux", "ToutDoux document", "", "", "", "x-office-document", nil, nil, nil, nil},
	{"application", "x-trash", "backup file", "", "", "", "", nil, nil, []string{".bak", ".old", ".sik"}, nil},
	{"application", "x-troff-man", "Manpage manual document", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".man"}, []int{827}},
	{"application", "x-troff-man-compressed", "manual page (compressed)", "", "", "", "text-x-generic", nil, nil, nil, nil},
	{"application", "x-tuberling", "potato", "", "", "", "", nil, nil, []string{".tuberling"}, nil},
	{"application", "x-turtle", "Turtle RDF document", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"application", "x-tzo", "Tar archive (LZO-compressed)", "", "", "", "package-x-generic", nil, []string{"application/x-lzop"}, []string{".tar.lzo", ".tzo"}, []int{368}},
	{"application", "x-ufraw", "UFRaw ID image", "UFRaw", "Unidentified Flying Raw", "", "image-x-generic", nil, []string{"application/xml"}, []string{".ufraw"}, []int{527}},
	{"application", "x-uml", "Umbrello UML Modeller file", "", "", "", "", nil, nil, []string{".xmi", ".xmi.tgz", ".xmi.tar.bz2"}, nil},
	{"application", "x-ustar", "Ustar archive", "", "", "", "package-x-generic", nil, nil, []string{".ustar"}, nil},
	{"application", "x-virtual-boy-rom", "Virtual Boy ROM", "", "", "", "application-x-executable", nil, nil, []string{".vb"}, nil},
	{"application", "x-virtualbox-hdd", "Virtual Hard Disk", "", "", "virtualbox-hdd", "", nil, nil, []string{".hdd"}, nil},
	{"application", "x-virtualbox-ova", "Open Virtualization Format Archive", "", "", "virtualbox-ova", "", nil, nil, []string{".ova"}, nil},
	{"application", "x-virtualbox-ovf", "Open Virtualization Format", "", "", "virtualbox-ovf", "", nil, nil, []string{".ovf"}, nil},
	{"application", "x-virtualbox-vbox", "VirtualBox Machine Definition", "", "", "virtualbox-vbox", "", nil, nil, []string{".vbox"}, nil},
	{"application", "x-virtualbox-vbox-extpack", "VirtualBox Extension Pack", "", "", "virtualbox-vbox-extpack", "", nil, nil, []string{".vbox-extpack"}, nil},
	{"application", "x-virtualbox-vdi", "Virtual Disk Image", "", "", "virtualbox-vdi", "", nil, nil, []string{".vdi"}, nil},
	{"application", "x-virtualbox-vhd", "Virtual Hard Disk", "", "", "virtualbox-vhd", "", nil, nil, []string{".vhd"}, nil},
	{"application", "x-virtualbox-vmdk", "Virtual Machine Disk Format", "", "", "virtualbox-vmdk", "", nil, nil, []string{".vmdk"}, nil},
	{"application", "x-vmware-enc-vm", "VMware encrypted virtual machine", "", "", "", "", nil, nil, []string{".vmx"}, nil},
	{"application", "x-vmware-snapshot", "VMware virtual machine snapshot", "", "", "", "", nil, nil, []string{".vmsn"}, nil},
	{"application", "x-vmware-team", "VMware team", "", "", "", "", nil, nil, []string{".vmtm"}, nil},
	{"application", "x-vmware-vm", "VMware virtual machine", "", "", "", "", nil, nil, []string{".vmx"}, nil},
	{"application", "x-vmware-vmdisk", "VMware virtual disk", "", "", "", "", nil, nil, []string{".vmdk"}, nil},
	{"application", "x-vmware-vmfoundry", "VMware virtual machine foundry", "", "", "", "", nil, nil, []string{".vmxf"}, nil},
	{"application", "x-vnd.akonadi.calendar.event", "iCal Calendar Event Component", "", "", "", "", nil, []string{"text/calendar"}, nil, []int{819}},
	{"application", "x-vnd.akonadi.calendar.freebusy", "iCal Calendar FreeBusy Component", "", "", "", "", nil, []string{"text/calendar"}, nil, []int{819}},
	{"application", "x-vnd.akonadi.calendar.journal", "iCal Calendar Journal Component", "", "", "", "", nil, []string{"text/calendar"}, nil, []int{819}},
	{"application", "x-vnd.akonadi.calendar.todo", "iCal Calendar TODO Component", "", "", "", "", nil, []string{"text/calendar"}, nil, []int{819}},
	{"application", "x-vnd.akonadi.collection.virtual", "Virtual Akonadi Collection", "", "", "", "", nil, nil, nil, nil},
	{"application", "x-vnd.kde.kplato", "KPlato project management document", "", "", "", "", nil, nil, []string{".kplato"}, nil},
	{"application", "x-vnd.kde.kplato.work", "KPlato project management work package", "", "", "", "", nil, nil, []string{".kplatowork"}, nil},
	{"application", "x-vnd.kde.kugar.mixed", "Kugar archive", "", "", "", "", nil, nil, []string{".kug"}, nil},
	{"application", "x-vnd.kde.okteta.structure", "Okteta Structure definition", "", "", "", "", nil, []string{"application/xml"}, []string{".osd"}, []int{527}},
	{"application", "x-vnd.kde.plan", "Calligra Plan project management document", "", "", "", "", nil, nil, []string{".plan"}, nil},
	{"application", "x-vnd.kde.plan.work", "Calligra Plan work package document", "", "", "", "", nil, nil, []string{".planwork"}, nil},
	{"application", "x-wais-source", "WAIS source code", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".src"}, []int{827}},
	{"application", "x-webarchive", "web archive", "", "", "", "", nil, []string{"application/x-compressed-tar", "application/x-gzip"}, []string{".war"}, []int{233, 14}},
	{"application", "x-wii-rom", "Wii disc image", "", "", "", "application-x-executable", []string{"application/x-wii-iso-image", "application/x-wbfs", "application/x-wia"}, nil, []string{".iso"}, nil},
	{"application", "x-wii-wad", "WiiWare bundle", "", "", "", "application-x-executable", nil, nil, []string{".wad"}, nil},
	{"application", "x-windows-themepack", "Microsoft Windows theme pack", "", "", "", "package-x-generic", nil, []string{"application/vnd.ms-cab-compressed"}, []string{".themepack"}, []int{102}},
	{"application", "x-wonderswan-color-rom", "Bandai WonderSwan Color ROM", "", "", "", "application-x-executable", nil, nil, []string{".wsc"}, nil},
	{"application", "x-wonderswan-rom", "Bandai WonderSwan ROM", "", "", "", "application-x-executable", nil, nil, []string{".ws"}, nil},
	{"application", "x-wpg", "WordPerfect/Drawperfect image", "", "", "", "image-x-generic", nil, nil, []string{".wpg"}, nil},
	{"application", "x-wwf", "WWF document", "", "", "", "x-office-document", []string{"application/wwf"}, []string{"application/pdf"}, []string{".wwf"}, []int{35}},
	{"application", "x-x509-ca-cert", "DER/PEM/Netscape-encoded X.509 certificate", "", "", "", "text-x-generic", nil, nil, []string{".der", ".crt", ".cert", ".pem"}, nil},
	{"application", "x-xar", "XAR archive", "XAR", "eXtensible ARchive", "", "package-x-generic", nil, nil, []string{".xar", ".pkg"}, nil},
	{"application", "x-xbel", "XBEL bookmarks", "XBEL", "XML Bookmark Exchange Language", "", "text-html", nil, []string{"application/xml"}, []string{".xbel"}, []int{527}},
	{"application", "x-xpinstall", "XPInstall installer module", "", "", "", "", nil, []string{"application/zip"}, []string{".xpi"}, []int{533}},
	{"application", "x-xz", "XZ archive", "", "", "", "package-x-generic", nil, nil, []string{".xz"}, nil},
	{"application", "x-xz-compressed-tar", "Tar archive (XZ-compressed)", "", "", "", "package-x-generic", nil, []string{"application/x-xz"}, []string{".tar.xz", ".txz"}, []int{518}},
	{"application", "x-xzpdf", "PDF document (XZ-compressed)", "", "", "", "x-office-document", nil, []string{"application/x-xz"}, []string{".pdf.xz"}, []int{518}},
	{"application", "x-yaml", "YAML document", "YAML", "YAML Ain't Markup Language", "", "text-x-generic", []string{"text/yaml", "text/x-yaml"}, []string{"text/plain"}, []string{".yaml", ".yml"}, []int{827}},
	{"application", "x-zerosize", "empty document", "", "", "", "", nil, nil, nil, nil},
	{"application", "x-zip-compressed-fb2", "Compressed FictionBook document", "", "", "", "", nil, []string{"application/zip"}, []string{".fb2.zip"}, []int{533}},
	{"application", "x-zoo", "Zoo archive", "", "", "", "package-x-generic", nil, nil, []string{".zoo"}, nil},
	{"application", "xhtml+xml", "XHTML page", "XHTML", "Extensible HyperText Markup Language", "", "text-html", nil, []string{"application/xml"}, []string{".xhtml", ".xht", ".html", ".htm"}, []int{527}},
	{"application", "xliff+xml", "XLIFF translation file", "XLIFF", "XML Localization Interchange File Format", "", "text-x-generic", []string{"application/x-xliff"}, []string{"application/xml"}, []string{".xlf", ".xliff"}, []int{527}},
	{"application", "xml", "XML document", "XML", "eXtensible Markup Language", "", "text-html", []string{"text/xml"}, []string{"text/plain"}, []string{".xml", ".xbl", ".xsd", ".rng"}, []int{827}},
	{"application", "xml-dtd", "DTD file", "DTD", "Document Type Definition", "", "text-x-generic", []string{"text/x-dtd"}, []string{"text/plain"}, []string{".dtd"}, []int{827}},
	{"application", "xml-external-parsed-entity", "XML entities document", "XML", "eXtensible Markup Language", "", "text-html", []string{"text/xml-external-parsed-entity"}, []string{"application/xml"}, []string{".ent"}, []int{527}},
	{"application", "xsd", "W3C XML schema", "", "", "", "", nil, []string{"application/xml"}, []string{".xsd"}, []int{527}},
	{"application", "xslt+xml", "XSLT stylesheet", "XSLT", "eXtensible Stylesheet Language Transformation", "", "text-x-generic", nil, []string{"application/xml"}, []string{".xsl", ".xslt"}, []int{527}},
	{"application", "xspf+xml", "XSPF playlist", "XSPF", "XML Shareable Playlist Format", "", "audio-x-generic", []string{"application/x-xspf+xml"}, []string{"application/xml"}, []string{".xspf"}, []int{527}},
	{"application", "zip", "Zip archive", "", "", "", "package-x-generic", []string{"application/x-zip-compressed", "application/x-zip"}, nil, []string{".zip"}, nil},
	{"application", "zlib", "Zlib archive", "", "", "", "package-x-generic", nil, nil, []string{".zz"}, nil},
	{"audio", "AMR", "AMR audio", "AMR", "Adaptive Multi-Rate", "", "", []string{"audio/amr-encrypted"}, nil, []string{".amr"}, nil},
	{"audio", "AMR-WB", "AMR-WB audio", "AMR-WB", "Adaptive Multi-Rate Wideband", "", "", []string{"audio/amr-wb-encrypted"}, nil, []string{".awb"}, nil},
	{"audio", "aac", "AAC audio", "AAC", "Advanced Audio Coding", "", "", []string{"audio/x-aac"}, nil, []string{".aac", ".adts", ".ass"}, nil},
	{"audio", "ac3", "Dolby Digital audio", "", "", "", "", nil, nil, []string{".ac3"}, nil},
	{"audio", "annodex", "Annodex Audio", "", "", "", "", []string{"audio/x-annodex"}, []string{"application/annodex"}, []string{".axa"}, []int{3}},
	{"audio", "basic", "ULAW (Sun) audio", "", "", "", "", nil, nil, []string{".au", ".snd"}, nil},
	{"audio", "flac", "FLAC audio", "", "", "", "", []string{"audio/x-flac"}, nil, []string{".flac"}, nil},
	{"audio", "midi", "MIDI audio", "", "", "", "", []string{"audio/x-midi"}, nil, []string{".mid", ".midi", ".kar"}, nil},
	{"audio", "mp2", "MP2 audio", "", "", "", "", []string{"audio/x-mp2"}, nil, []string{".mp2"}, nil},
	{"audio", "mp4", "MPEG-4 audio", "", "", "", "", []string{"audio/x-m4a", "audio/m4a"}, nil, []string{".m4a", ".f4a"}, nil},
	{"audio", "mpeg", "MP3 audio", "", "", "", "", []string{"audio/x-mp3", "audio/x-mpg", "audio/x-mpeg", "audio/mp3"}, nil, []string{".mp3", ".mpga"}, nil},
	{"audio", "ogg", "Ogg Audio", "", "", "", "", []string{"audio/x-ogg"}, []string{"application/ogg"}, []string{".oga", ".ogg", ".opus"}, []int{32}},
	{"audio", "prs.sid", "Commodore 64 audio", "", "", "", "", nil, nil, []string{".sid", ".psid"}, nil},
	{"audio", "usac", "USAC audio", "USAC", "Unified Speech and Audio Coding", "", "", nil, nil, []string{".loas", ".xhe"}, nil},
	{"audio", "vnd.dts", "DTS audio", "", "", "", "", []string{"audio/x-dts"}, nil, []string{".dts"}, nil},
	{"audio", "vnd.dts.hd", "DTSHD audio", "", "", "", "", []string{"audio/x-dtshd"}, []string{"audio/vnd.dts"}, []string{".dtshd"}, []int{549}},
	{"audio", "vnd.rn-realaudio", "RealAudio document", "", "", "", "", []string{"audio/x-pn-realaudio", "audio/vnd.m-realaudio"}, nil, []string{".ra", ".rax"}, nil},
	{"audio", "webm", "WebM audio", "", "", "", "", nil, []string{"video/webm"}, nil, []int{968}},
	{"audio", "x-adpcm", "PCM audio", "", "", "", "", nil, nil, nil, nil},
	{"audio", "x-aifc", "AIFC audio", "AIFC", "Audio Interchange File format Compressed", "", "", []string{"audio/x-aiffc"}, []string{"application/x-iff"}, []string{".aifc", ".aiffc"}, []int{302}},
	{"audio", "x-aiff", "AIFF/Amiga/Mac audio", "AIFF", "Audio Interchange File Format", "", "", nil, []string{"application/x-iff"}, []string{".aiff", ".aif"}, []int{302}},
	{"audio", "x-amzxml", "AmazonMP3 download file", "", "", "", "", nil, nil, []string{".amz"}, nil},
	{"audio", "x-ape", "Monkey's audio", "", "", "", "", nil, nil, []string{".ape"}, nil},
	{"audio", "x-flac+ogg", "Ogg FLAC audio", "", "", "", "", []string{"audio/x-oggflac"}, []string{"audio/ogg"}, []string{".oga", ".ogg"}, []int{546}},
	{"audio", "x-gsm", "GSM 06.10 audio", "GSM", "Global System for Mobile communications", "", "", nil, nil, []string{".gsm"}, nil},
	{"audio", "x-iriver-pla", "iRiver Playlist", "", "", "", "", nil, nil, []string{".pla"}, nil},
	{"audio", "x-it", "Impulse Tracker audio", "", "", "", "", nil, nil, []string{".it"}, nil},
	{"audio", "x-m4b", "MPEG-4 audio book", "", "", "", "", nil, []string{"audio/mp4"}, []string{".m4b", ".f4b"}, []int{544}},
	{"audio", "x-m4r", "MPEG-4 Ringtone", "", "", "", "", nil, []string{"video/mp4"}, []string{".m4r"}, []int{960}},
	{"audio", "x-matroska", "Matroska audio", "", "", "", "", nil, []string{"application/x-matroska"}, []string{".mka"}, []int{374}},
	{"audio", "x-minipsf", "MiniPSF audio", "MiniPSF", "Miniature Portable Sound Format", "", "", nil, []string{"audio/x-psf"}, []string{".minipsf"}, []int{575}},
	{"audio", "x-mo3", "compressed Tracker audio", "", "", "", "", nil, nil, []string{".mo3"}, nil},
	{"audio", "x-mod", "Amiga SoundTracker audio", "", "", "", "", nil, nil, []string{".mod", ".ult", ".uni", ".m15", ".mtm", ".669", ".med"}, nil},
	{"audio", "x-mpegurl", "MP3 audio (streamed)", "", "", "", "", []string{"audio/mpegurl", "application/m3u", "audio/x-mp3-playlist", "audio/m3u", "audio/x-m3u"}, []string{"text/plain"}, []string{".m3u", ".m3u8", ".vlc"}, []int{827}},
	{"audio", "x-ms-asx", "Microsoft ASX playlist", "", "", "", "", []string{"video/x-ms-wvx", "video/x-ms-wax", "video/x-ms-wmx", "application/x-ms-asx"}, nil, []string{".asx", ".wax", ".wvx", ".wmx"}, nil},
	{"audio", "x-ms-wma", "Windows Media audio", "", "", "", "", []string{"audio/wma"}, []string{"application/vnd.ms-asf"}, []string{".wma"}, []int{101}},
	{"audio", "x-musepack", "Musepack audio", "", "", "", "", nil, nil, []string{".mpc", ".mpp", ".mp+"}, nil},
	{"audio", "x-opus+ogg", "Opus audio", "", "", "", "", nil, []string{"audio/ogg"}, []string{".opus"}, []int{546}},
	{"audio", "x-pn-audibleaudio", "Audible.Com audio", "", "", "", "", []string{"audio/vnd.audible", "audio/vnd.audible.aax"}, nil, []string{".aa", ".aax"}, nil},
	{"audio", "x-pn-realaudio-plugin", "RealAudio plugin file", "", "", "", "", nil, nil, nil, nil},
	{"audio", "x-psf", "PSF audio", "PSF", "Portable Sound Format", "", "", nil, nil, []string{".psf"}, nil},
	{"audio", "x-psflib", "PSFlib audio library", "PSFlib", "Portable Sound Format Library", "", "", nil, []string{"audio/x-psf"}, []string{".psflib"}, []int{575}},
	{"audio", "x-riff", "RIFF audio", "", "", "", "", nil, nil, nil, nil},
	{"audio", "x-s3m", "Scream Tracker 3 audio", "", "", "", "", nil, nil, []string{".s3m"}, nil},
	{"audio", "x-scpls", "MP3 ShoutCast playlist", "", "", "", "", []string{"application/pls", "audio/scpls"}, nil, []string{".pls"}, nil},
	{"audio", "x-speex", "Speex audio", "", "", "", "", nil, nil, []string{".spx"}, nil},
	{"audio", "x-speex+ogg", "Ogg Speex audio", "", "", "", "", nil, []string{"audio/ogg"}, []string{".oga", ".ogg"}, []int{546}},
	{"audio", "x-stm", "Scream Tracker audio", "", "", "", "", nil, nil, []string{".stm"}, nil},
	{"audio", "x-tta", "TrueAudio audio", "", "", "", "", []string{"audio/tta"}, nil, []string{".tta"}, nil},
	{"audio", "x-voc", "VOC audio", "", "", "", "", nil, nil, []string{".voc"}, nil},
	{"audio", "x-vorbis+ogg", "Ogg Vorbis audio", "", "", "", "", []string{"audio/vorbis", "audio/x-vorbis"}, []string{"audio/ogg"}, []string{".oga", ".ogg"}, []int{546}},
	{"audio", "x-wav", "WAV audio", "", "", "", "", []string{"audio/wav", "audio/vnd.wave"}, nil, []string{".wav"}, nil},
	{"audio", "x-wavpack", "WavPack audio", "", "", "", "", nil, nil, []string{".wv", ".wvp"}, nil},
	{"audio", "x-wavpack-correction", "WavPack audio correction file", "", "", "", "", nil, nil, []string{".wvc"}, nil},
	{"audio", "x-xi", "Scream Tracker instrument", "", "", "", "", nil, nil, []string{".xi"}, nil},
	{"audio", "x-xm", "FastTracker II audio", "", "", "", "", nil, nil, []string{".xm"}, nil},
	{"audio", "x-xmf", "XMF audio", "XMF", "eXtensible Music Format", "", "", []string{"audio/xmf", "audio/mobile-xmf"}, nil, []string{".xmf"}, nil},
	{"font", "collection", "Font collection", "", "", "", "font-x-generic", nil, nil, []string{".ttc"}, nil},
	{"font", "otf", "OpenType font", "", "", "", "font-x-generic", []string{"application/x-font-otf"}, []string{"font/ttf"}, []string{".otf"}, []int{594}},
	{"font", "ttf", "TrueType font", "", "", "", "font-x-generic", []string{"application/x-font-ttf"}, nil, []string{".ttf"}, nil},
	{"font", "woff", "WOFF font", "WOFF", "Web Open Font Format", "", "font-x-generic", []string{"application/font-woff"}, nil, []string{".woff"}, nil},
	{"font", "woff2", "WOFF2 font", "WOFF2", "Web Open Font Format 2.0", "", "font-x-generic", nil, nil, []string{".woff2"}, nil},
	{"image", "bmp", "Windows BMP image", "", "", "", "", []string{"image/x-bmp", "image/x-MS-bmp"}, nil, []string{".bmp", ".dib"}, nil},
	{"image", "cgm", "Computer Graphics Metafile", "", "", "", "", nil, nil, []string{".cgm"}, nil},
	{"image", "dpx", "DPX image", "DPX", "Digital Moving Picture Exchange", "", "", nil, nil, nil, nil},
	{"image", "emf", "EMF image", "EMF", "Enhanced MetaFile", "", "", []string{"image/x-emf", "application/x-emf", "application/emf"}, nil, []string{".emf"}, nil},
	{"image", "fax-g3", "CCITT G3 fax", "", "", "", "", nil, nil, []string{".g3"}, nil},
	{"image", "fits", "FITS document", "FITS", "Flexible Image Transport System", "", "", []string{"image/x-fits"}, nil, []string{".fits"}, nil},
	{"image", "g3fax", "G3 fax image", "", "", "", "", nil, nil, nil, nil},
	{"image", "gif", "GIF image", "", "", "", "", nil, nil, []string{".gif"}, nil},
	{"image", "heif", "HEIF image", "HEIF", "High Efficiency Image File", "", "", []string{"image/heic", "image/heic-sequence", "image/heif-sequence"}, nil, []string{".heic", ".heif"}, nil},
	{"image", "ief", "IEF image", "", "", "", "", nil, nil, []string{".ief"}, nil},
	{"image", "jp2", "JPEG-2000 JP2 image", "JP2", "JPEG-2000", "", "", []string{"image/jpeg2000", "image/jpeg2000-image", "image/x-jpeg2000-image"}, nil, []string{".jp2", ".jpg2"}, nil},
	{"image", "jpeg", "JPEG image", "", "", "", "", []string{"image/pjpeg"}, nil, []string{".jpg", ".jpeg", ".jpe"}, nil},
	{"image", "jpm", "JPEG-2000 JPM image", "JPM", "JPEG-2000 Mixed", "", "", nil, nil, []string{".jpm", ".jpgm"}, nil},
	{"image", "jpx", "JPEG-2000 JPX image", "JPX", "JPEG-2000 eXtended", "", "", nil, nil, []string{".jpf", ".jpx"}, nil},
	{"image", "ktx", "Khronos texture image", "", "", "", "", nil, nil, []string{".ktx"}, nil},
	{"image", "openraster", "OpenRaster archiving image", "", "", "", "", nil, []string{"application/zip"}, []string{".ora"}, []int{533}},
	{"image", "png", "PNG image", "", "", "", "", nil, nil, []string{".png"}, nil},
	{"image", "rle", "Run Length Encoded bitmap image", "", "", "", "", nil, nil, []string{".rle"}, nil},
	{"image", "svg+xml", "SVG image", "SVG", "Scalable Vector Graphics", "", "", nil, []string{"application/xml"}, []string{".svg"}, []int{527}},
	{"image", "svg+xml-compressed", "compressed SVG image", "SVG", "Scalable Vector Graphics", "", "", nil, []string{"application/gzip"}, []string{".svgz"}, []int{14}},
	{"image", "tiff", "TIFF image", "TIFF", "Tagged Image File Format", "", "", nil, nil, []string{".tif", ".tiff"}, nil},
	{"image", "vnd.adobe.photoshop", "Photoshop image", "", "", "", "", []string{"image/psd", "image/x-psd", "image/photoshop", "image/x-photoshop", "application/photoshop", "application/x-photoshop"}, nil, []string{".psd"}, nil},
	{"image", "vnd.djvu", "DjVu image", "", "", "", "", []string{"image/x-djvu", "image/x.djvu"}, nil, []string{".djvu", ".djv"}, nil},
	{"image", "vnd.djvu+multipage", "DjVu document", "", "", "", "x-office-document", nil, []string{"image/vnd.djvu"}, []string{".djvu", ".djv"}, []int{619}},
	{"image", "vnd.dwg", "AutoCAD image", "", "", "", "", nil, nil, []string{".dwg"}, nil},
	{"image", "vnd.dxf", "DXF vector image", "", "", "", "", nil, nil, []string{".dxf"}, nil},
	{"image", "vnd.microsoft.icon", "Windows icon", "", "", "", "", []string{"application/ico", "image/ico", "image/icon", "image/x-ico", "image/x-icon", "text/ico"}, nil, []string{".ico"}, nil},
	{"image", "vnd.ms-modi", "Microsoft Document Imaging format", "MDI", "Microsoft Document Imaging", "", "", nil, nil, []string{".mdi"}, nil},
	{"image", "vnd.rn-realpix", "RealPix document", "", "", "", "", nil, nil, []string{".rp"}, nil},
	{"image", "vnd.wap.wbmp", "WBMP image", "WBMP", "WAP bitmap", "", "", nil, nil, []string{".wbmp"}, nil},
	{"image", "vnd.zbrush.pcx", "PCX image", "PCX", "PiCture eXchange", "", "", []string{"image/x-pcx"}, nil, []string{".pcx"}, nil},
	{"image", "webp", "WebP image", "", "", "", "", nil, nil, []string{".webp"}, nil},
	{"image", "wmf", "WMF image", "WMF", "Windows Metafile", "", "", []string{"image/x-wmf", "image/x-win-metafile", "application/x-wmf", "application/wmf", "application/x-msmetafile"}, nil, []string{".wmf"}, nil},
	{"image", "x-3ds", "3D Studio image", "", "", "", "", nil, nil, []string{".3ds"}, nil},
	{"image", "x-adobe-dng", "Adobe DNG negative", "DNG", "Digital Negative", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".dng"}, []int{638, 617}},
	{"image", "x-applix-graphics", "Applix Graphics image", "", "", "", "", nil, nil, []string{".ag"}, nil},
	{"image", "x-bzeps", "EPS image (bzip-compressed)", "", "", "", "", nil, []string{"application/x-bzip"}, []string{".eps.bz2", ".epsi.bz2", ".epsf.bz2"}, []int{217}},
	{"image", "x-canon-cr2", "Canon CR2 raw image", "CR2", "Canon Raw 2", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".cr2"}, []int{638, 617}},
	{"image", "x-canon-crw", "Canon CRW raw image", "CRW", "Canon RaW", "", "", nil, []string{"image/x-dcraw"}, []string{".crw"}, []int{638}},
	{"image", "x-cmu-raster", "CMU raster image", "", "", "", "", nil, nil, []string{".ras"}, nil},
	{"image", "x-compressed-xcf", "compressed GIMP image", "", "", "", "", nil, nil, []string{".xcf.gz", ".xcf.bz2"}, nil},
	{"image", "x-dcraw", "digital raw image", "", "", "", "", nil, nil, nil, nil},
	{"image", "x-dds", "DirectDraw surface", "", "", "", "", nil, nil, []string{".dds"}, nil},
	{"image", "x-dib", "DIB image", "DIB", "Device Independent Bitmap", "", "", nil, nil, nil, nil},
	{"image", "x-eps", "EPS image", "EPS", "Encapsulated PostScript", "", "", nil, []string{"application/postscript"}, []string{".eps", ".epsi", ".epsf"}, []int{54}},
	{"image", "x-exr", "EXR image", "", "", "", "", nil, nil, []string{".exr"}, nil},
	{"image", "x-fpx", "FPX image", "FPX", "FlashPiX", "", "", nil, nil, nil, nil},
	{"image", "x-fuji-raf", "Fuji RAF raw image", "RAF", "RAw Format", "", "", nil, []string{"image/x-dcraw"}, []string{".raf"}, []int{638}},
	{"image", "x-gimp-gbr", "GIMP brush", "", "", "", "", nil, nil, []string{".gbr"}, nil},
	{"image", "x-gimp-gih", "GIMP brush pipe", "", "", "", "", nil, nil, []string{".gih"}, nil},
	{"image", "x-gimp-pat", "GIMP pattern", "", "", "", "", nil, nil, []string{".pat"}, nil},
	{"image", "x-gzeps", "EPS image (gzip-compressed)", "", "", "", "", nil, []string{"application/gzip"}, []string{".eps.gz", ".epsi.gz", ".epsf.gz"}, []int{14}},
	{"image", "x-hdr", "HDR image", "HDR", "High Dynamic Range", "", "", nil, nil, []string{".hdr", ".pic"}, nil},
	{"image", "x-icns", "MacOS X icon", "", "", "", "", nil, nil, []string{".icns"}, nil},
	{"image", "x-ilbm", "ILBM image", "ILBM", "InterLeaved BitMap", "", "", []string{"image/x-iff"}, []string{"application/x-iff"}, []string{".iff", ".ilbm", ".lbm"}, []int{302}},
	{"image", "x-jng", "JNG image", "JNG", "JPEG Network Graphics", "", "", nil, nil, []string{".jng"}, nil},
	{"image", "x-jp2-codestream", "JPEG-2000 codestream", "", "", "", "", nil, nil, []string{".j2c", ".j2k", ".jpc"}, nil},
	{"image", "x-kde-raw", "KDE raw image formats", "", "", "", "", nil, []string{"image/x-dcraw"}, []string{".bay", ".bmq", ".cs1", ".cs2", ".erf", ".fff", ".hrd", ".mdc", ".mos", ".pnx", ".rdc"}, []int{638}},
	{"image", "x-kodak-dcr", "Kodak DCR raw image", "DCR", "Digital Camera Raw", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".dcr"}, []int{638, 617}},
	{"image", "x-kodak-k25", "Kodak K25 raw image", "K25", "Kodak DC25", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".k25"}, []int{638, 617}},
	{"image", "x-kodak-kdc", "Kodak KDC raw image", "KDC", "Kodak Digital Camera", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".kdc"}, []int{638, 617}},
	{"image", "x-lwo", "LightWave object", "", "", "", "", nil, nil, []string{".lwo", ".lwob"}, nil},
	{"image", "x-lws", "LightWave scene", "", "", "", "", nil, nil, []string{".lws"}, nil},
	{"image", "x-macpaint", "MacPaint Bitmap image", "", "", "", "", nil, nil, []string{".pntg"}, nil},
	{"image", "x-minolta-mrw", "Minolta MRW raw image", "MRW", "Minolta RaW", "", "", nil, []string{"image/x-dcraw"}, []string{".mrw"}, []int{638}},
	{"image", "x-msod", "Office drawing", "", "", "", "", nil, nil, []string{".msod"}, nil},
	{"image", "x-niff", "NIFF image", "", "", "", "", nil, nil, nil, nil},
	{"image", "x-nikon-nef", "Nikon NEF raw image", "NEF", "Nikon Electronic Format", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".nef"}, []int{638, 617}},
	{"image", "x-olympus-orf", "Olympus ORF raw image", "ORF", "Olympus Raw Format", "", "", nil, []string{"image/x-dcraw"}, []string{".orf"}, []int{638}},
	{"image", "x-panasonic-rw", "Panasonic raw image", "", "", "", "", []string{"image/x-panasonic-raw"}, []string{"image/x-dcraw"}, []string{".raw"}, []int{638}},
	{"image", "x-panasonic-rw2", "Panasonic raw2 image", "", "", "", "", []string{"image/x-panasonic-raw2"}, []string{"image/x-dcraw"}, []string{".rw2"}, []int{638}},
	{"image", "x-pentax-pef", "Pentax PEF raw image", "PEF", "Pentax Electronic Format", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".pef"}, []int{638, 617}},
	{"image", "x-photo-cd", "PCD image", "PCD", "PhotoCD", "", "", nil, nil, []string{".pcd"}, nil},
	{"image", "x-pic", "Softimage PIC image", "", "", "", "", nil, nil, []string{".pic"}, nil},
	{"image", "x-pict", "Macintosh Quickdraw/PICT drawing", "", "", "", "", nil, nil, []string{".pct", ".pict", ".pict1", ".pict2"}, nil},
	{"image", "x-portable-anymap", "PNM image", "", "", "", "", nil, nil, []string{".pnm"}, nil},
	{"image", "x-portable-bitmap", "PBM image", "PBM", "Portable BitMap", "", "", nil, []string{"image/x-portable-anymap"}, []string{".pbm"}, []int{672}},
	{"image", "x-portable-graymap", "PGM image", "PGM", "Portable GrayMap", "", "", nil, []string{"image/x-portable-anymap"}, []string{".pgm"}, []int{672}},
	{"image", "x-portable-pixmap", "PPM image", "PPM", "Portable PixMap", "", "", nil, []string{"image/x-portable-anymap"}, []string{".ppm"}, []int{672}},
	{"image", "x-quicktime", "QuickTime image", "", "", "", "", nil, nil, []string{".qtif", ".qif"}, nil},
	{"image", "x-rgb", "RGB image", "", "", "", "", nil, nil, []string{".rgb"}, nil},
	{"image", "x-sgi", "SGI image", "", "", "", "", nil, nil, []string{".sgi"}, nil},
	{"image", "x-sigma-x3f", "Sigma X3F raw image", "X3F", "X3 Foveon", "", "", nil, []string{"image/x-dcraw"}, []string{".x3f"}, []int{638}},
	{"image", "x-skencil", "Skencil document", "", "", "", "", nil, nil, []string{".sk", ".sk1"}, nil},
	{"image", "x-sony-arw", "Sony ARW raw image", "ARW", "Alpha Raw format", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".arw"}, []int{638, 617}},
	{"image", "x-sony-sr2", "Sony SR2 raw image", "SR2", "Sony Raw format 2", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".sr2"}, []int{638, 617}},
	{"image", "x-sony-srf", "Sony SRF raw image", "SRF", "Sony Raw Format", "", "", nil, []string{"image/x-dcraw", "image/tiff"}, []string{".srf"}, []int{638, 617}},
	{"image", "x-sun-raster", "Sun raster image", "", "", "", "", nil, nil, []string{".sun"}, nil},
	{"image", "x-svm", "StarView Metafile", "", "", "", "", nil, nil, []string{".svm"}, nil},
	{"image", "x-tga", "TGA image", "TGA", "Truevision Graphics Adapter", "", "", []string{"image/x-icb"}, nil, []string{".tga", ".icb", ".tpic", ".vda", ".vst"}, nil},
	{"image", "x-tiff-multipage", "Multi-page TIFF image", "TIFF", "Tagged Image File Format", "", "", nil, []string{"image/tiff"}, nil, []int{617}},
	{"image", "x-webp", "WebP image", "", "", "", "", nil, nil, []string{".webp"}, nil},
	{"image", "x-win-bitmap", "Windows cursor", "", "", "", "", nil, nil, []string{".cur"}, nil},
	{"image", "x-xbitmap", "XBM image", "XBM", "X BitMap", "", "", nil, nil, []string{".xbm"}, nil},
	{"image", "x-xcf", "GIMP image", "", "", "", "", nil, nil, []string{".xcf"}, nil},
	{"image", "x-xcursor", "X11 cursor", "", "", "", "", nil, nil, nil, nil},
	{"image", "x-xfig", "XFig image", "", "", "", "", nil, nil, []string{".fig"}, nil},
	{"image", "x-xpixmap", "XPM image", "XPM", "X PixMap", "", "", []string{"image/x-xpm"}, nil, []string{".xpm"}, nil},
	{"image", "x-xwindowdump", "X window image", "", "", "", "", nil, nil, []string{".xwd"}, nil},
	{"inode", "blockdevice", "block device", "", "", "", "", nil, nil, nil, nil},
	{"inode", "chardevice", "character device", "", "", "", "", nil, nil, nil, nil},
	{"inode", "directory", "folder", "", "", "", "folder", []string{"x-directory/normal"}, nil, nil, nil},
	{"inode", "fifo", "pipe", "", "", "", "", nil, nil, nil, nil},
	{"inode", "mount-point", "mount point", "", "", "", "", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "socket", "socket", "", "", "", "", nil, nil, nil, nil},
	{"inode", "symlink", "symbolic link", "", "", "", "", nil, nil, nil, nil},
	{"inode", "vnd.kde.bluedevil.device", "Device", "", "", "", "video-display", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.bluedevil.service", "Service", "", "", "", "preferences-system-bluetooth", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.device.printer", "Printer", "", "", "", "printer", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.device.router", "Router", "", "", "", "network-server", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.device.scanner", "Scanner", "", "", "", "scanner", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.device.server", "Server", "", "", "", "network-server", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.device.unknown", "Unknown device", "", "", "", "network-server", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.device.workstation", "Workstation", "", "", "", "computer", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.network", "Network", "", "", "", "network-workgroup", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.acrobat-server", "Adobe Acrobat server", "", "", "", "application-pdf", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.adobe-vc", "Adobe Version Cue", "", "", "", "services", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.afpovertcp", "AFP server", "", "", "", "folder-remote", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.airmouse", "Air Mouse server", "", "", "", "input-mouse", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.airport", "AirPort Base Station", "", "", "", "network-wireless", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.appletv-itunes", "Apple TV iTunes discovery", "", "", "", "services", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.appletv-pair", "Apple TV Pairing", "", "", "", "services", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.couchdb_location", "CouchDB server", "", "", "", "server-database", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.daap", "Digital Audio Access", "", "", "", "folder-sound", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.dacp", "iTunes Remote Control", "", "", "", "services", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.eppc", "Remote AppleEvents", "", "", "", "network-connect", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.ftp", "FTP server", "FTP", "File transfer protocol", "", "folder-remote", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.ftps", "FTPS server", "FTPS", "FTP over SSL", "", "folder-remote", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.ggz", "GGZ Server", "GGZ", "GGZ Gaming Zone", "", "applications-games", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.giver", "Giver Peer", "", "", "", "folder-remote", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.h323", "H323 Telephony", "", "", "", "phone", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.home-sharing", "iTunes Home Sharing", "", "", "", "services", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.http", "Web server", "", "", "", "folder-html", nil, []string{"inode/symlink"}, nil, []int{702}},
	{"inode", "vnd.kde.service.imap", "IMAP server", "", "", "", "email", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.ipp", "Internet Printing", "", "", "", "printer", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.kbattleship", "KBattleship game table", "", "", "", "kbattleship", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.kfourinline", "Four-in-line game table", "", "", "", "kfourinline", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.ksirk", "KSirk game table", "", "", "", "ksirk", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.ldap", "LDAP server", "", "", "", "user-group-properties", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.libvirt", "libvirt server", "", "", "", "computer", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.lobby", "Gobby server", "", "", "", "document-edit", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.lskat", "Lieutenant skat game server", "", "", "", "lskat", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.maemo-inf", "Maemo Info", "", "", "", "pda", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.net-assistant", "Apple Remote Desktop", "", "", "", "services", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.nfs", "NFS server", "NFS", "Network filesystem", "", "folder-remote", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.nssocketport", "NSSocketPort", "", "", "", "services", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.ntp", "Time server", "", "", "", "xclock", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.odisk", "Optical Disk Sharing", "", "", "", "media-optical", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.pdl-datastream", "PDL Printing", "", "", "", "printer", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.plasma", "Plasma service", "", "", "", "plasma", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.pop3", "POP3 server", "", "", "", "email", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.postgresql", "PostgreSQL server", "", "", "", "server-database", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.presence", "Chat", "", "", "", "im-user", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.printer", "Unix Printing", "", "", "", "printer", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.pulse-server", "Pulse server", "", "", "", "audio-card", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.pulse-sink", "Pulse sink", "", "", "", "speaker", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.pulse-source", "Pulse source", "", "", "", "audio-input-line", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.raop", "Remote Audio Output", "", "", "", "speaker", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.rdp", "RDP server", "", "", "", "krfb", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.realplayfavs", "RealPlayer Shared Favorites", "", "", "", "favorites", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.rfb", "Display server", "", "", "", "krfb", nil, []string{"inode/symlink"}, nil, []int{702}},
	{"inode", "vnd.kde.service.rsync", "RSync server", "", "", "", "folder-sync", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.sftp-ssh", "SFTP (ssh) server", "", "", "", "folder-remote", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.sip", "SIP Telephony", "", "", "", "phone", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.skype", "Skype Telephony", "", "", "", "phone", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.sleep-proxy", "Sleep Proxy", "", "", "", "services", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.smb", "SMB server", "", "", "", "folder-remote", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.ssh", "SSH server", "SSH", "Secure shell", "", "terminal", nil, []string{"inode/symlink"}, nil, []int{702}},
	{"inode", "vnd.kde.service.svn", "Subversion server", "", "", "", "folder-sync", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.telnet", "Telnet server", "", "", "", "terminal", nil, []string{"inode/symlink"}, nil, []int{702}},
	{"inode", "vnd.kde.service.touch-able", "iPhone and iPod touch Remote Controllable", "", "", "", "input-tablet", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.udisks-ssh", "Udisks server", "", "", "", "drive-harddisk", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.unknown", "Unknown service", "", "", "", "document", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.BasicDevice1", "UPnP Basic Device", "", "UPnP Universal Plug and Play", "", "network-server", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.DigitalSecurityCamera1", "UPnP Digital Security Camera", "", "UPnP Universal Plug and Play", "", "camera", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.HVAC1", "UPnP HVAC", "", "Heating, Ventilating, and Air Conditioning", "", "device", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.InternetGatewayDevice1", "UPnP Internet Gateway Device", "", "UPnP Universal Plug and Play", "", "network-server", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.LANDevice1", "UPnP LAN Device", "", "UPnP Universal Plug and Play", "", "network-wired", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.LightingControls1", "UPnP Lighting Controls", "", "UPnP Universal Plug and Play", "", "light", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.MediaRenderer1", "UPnP Media Renderer", "", "UPnP Universal Plug and Play", "", "video-television", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.MediaRenderer2", "UPnP Media Renderer", "", "UPnP Universal Plug and Play", "", "video-television", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.MediaServer1", "UPnP Media Server", "", "UPnP Universal Plug and Play", "", "folder-remote", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.MediaServer2", "UPnP Media Server", "", "UPnP Universal Plug and Play", "", "folder-remote", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.MediaServer3", "UPnP Media Server", "", "UPnP Universal Plug and Play", "", "folder-remote", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.PrinterBasic1", "UPnP Printer (Basic)", "", "UPnP Universal Plug and Play", "", "printer", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.PrinterEnhanced1", "UPnP Printer (Enhanced)", "", "UPnP Universal Plug and Play", "", "printer", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.RAClient1", "UPnP Remote Access Client", "", "UPnP Universal Plug and Play", "", "device", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.RADiscoveryAgent1", "UPnP Remote Access Discovery Agent", "", "UPnP Universal Plug and Play", "", "device", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.RAServer1", "UPnP Remote Access Server", "", "UPnP Universal Plug and Play", "", "device", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.RemoteUIClientDevice1", "UPnP Remote UI Client", "", "UPnP Universal Plug and Play", "", "device", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.RemoteUIServerDevice1", "UPnP Remote UI Server", "", "UPnP Universal Plug and Play", "", "device", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.Scanner1", "UPnP Scanner", "", "UPnP Universal Plug and Play", "", "scanner", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.SolarProtectionBlind1", "UPnP Solar Protection Blind", "", "UPnP Universal Plug and Play", "", "device", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.Unknown", "Unknown UPnP Device", "", "UPnP Universal Plug and Play", "", "device", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.WANConnectionDevice1", "UPnP WAN Connection Device", "", "UPnP Universal Plug and Play", "", "network-wired", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.WANDevice1", "UPnP WAN Device", "", "UPnP Universal Plug and Play", "", "network-wired", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.WFADevice1", "UPnP Wi-Fi Alliance Device", "", "UPnP Universal Plug and Play", "", "network-wireless", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.upnp.WLANAccessPointDevice1", "UPnP WLAN Access Point Device", "", "UPnP Universal Plug and Play", "", "network-wireless", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.webdav", "WebDav server", "", "", "", "folder-remote", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.webdavs", "WebDav secure server", "", "", "", "folder-remote", nil, []string{"inode/directory"}, nil, []int{698}},
	{"inode", "vnd.kde.service.workstation", "Workgroup Manager", "", "", "", "network-workgroup", nil, nil, nil, nil},
	{"inode", "vnd.kde.service.xmpp-server", "XMPP/Jabber server", "", "", "", "xchat", nil, nil, nil, nil},
	{"message", "delivery-status", "mail delivery report", "", "", "", "text-x-generic", nil, []string{"text/plain"}, nil, []int{827}},
	{"message", "disposition-notification", "mail disposition report", "", "", "", "text-x-generic", nil, []string{"text/plain"}, nil, []int{827}},
	{"message", "external-body", "reference to remote file", "", "", "", "text-x-generic", nil, nil, nil, nil},
	{"message", "news", "Usenet news message", "", "", "", "text-x-generic", nil, []string{"text/plain"}, nil, []int{827}},
	{"message", "partial", "partial email message", "", "", "", "text-x-generic", nil, []string{"text/plain"}, nil, []int{827}},
	{"message", "rfc822", "email message", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".eml"}, []int{827}},
	{"message", "x-gnu-rmail", "GNU mail message", "", "", "", "text-x-generic", nil, nil, nil, nil},
	{"model", "iges", "IGES document", "IGES", "Initial Graphics Exchange Specification", "", "x-office-document", nil, []string{"text/plain"}, []string{".igs", ".iges"}, []int{827}},
	{"model", "stl", "STL 3D model", "STL", "StereoLithography", "", "", []string{"model/x.stl-ascii", "model/x.stl-binary"}, nil, []string{".stl"}, nil},
	{"model", "vrml", "VRML document", "VRML", "Virtual Reality Modeling Language", "", "x-office-document", nil, []string{"text/plain"}, []string{".vrm", ".vrml", ".wrl"}, []int{827}},
	{"multipart", "alternative", "message in several formats", "", "", "", "", nil, nil, nil, nil},
	{"multipart", "appledouble", "Macintosh AppleDouble-encoded file", "", "", "", "", nil, nil, nil, nil},
	{"multipart", "digest", "message digest", "", "", "", "", nil, nil, nil, nil},
	{"multipart", "encrypted", "encrypted message", "", "", "", "", nil, nil, nil, nil},
	{"multipart", "mixed", "compound documents", "", "", "", "", nil, nil, nil, nil},
	{"multipart", "related", "compound document", "", "", "", "", nil, nil, nil, nil},
	{"multipart", "report", "mail system report", "", "", "", "", nil, nil, nil, nil},
	{"multipart", "signed", "signed message", "", "", "", "", nil, nil, nil, nil},
	{"multipart", "x-mixed-replace", "stream of data (server push)", "", "", "", "", nil, nil, nil, nil},
	{"text", "cache-manifest", "Web application cache manifest", "", "", "", "", nil, []string{"text/plain"}, []string{".manifest"}, []int{827}},
	{"text", "calendar", "VCS/ICS calendar", "VCS/ICS", "vCalendar/iCalendar", "", "", []string{"text/x-vcalendar", "application/ics"}, []string{"text/plain"}, []string{".vcs", ".ics"}, []int{827}},
	{"text", "css", "CSS stylesheet", "CSS", "Cascading Style Sheets", "", "", nil, []string{"text/plain"}, []string{".css"}, []int{827}},
	{"text", "csv", "CSV document", "CSV", "Comma Separated Values", "", "", []string{"text/x-comma-separated-values", "text/x-csv"}, []string{"text/plain"}, []string{".csv"}, []int{827}},
	{"text", "csv-schema", "CSV Schema document", "CSV", "Comma Separated Values", "", "", nil, []string{"text/plain"}, []string{".csvs"}, []int{827}},
	{"text", "enriched", "enriched text document", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "html", "HTML document", "HTML", "HyperText Markup Language", "", "", nil, []string{"text/plain"}, []string{".html", ".htm"}, []int{827}},
	{"text", "htmlh", "help page", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "markdown", "Markdown document", "", "", "", "", []string{"text/x-markdown"}, []string{"text/plain"}, []string{".md", ".mkd", ".markdown"}, []int{827}},
	{"text", "plain", "plain text document", "", "", "", "", nil, nil, []string{".txt", ".asc", ".doc"}, nil},
	{"text", "rfc822-headers", "email headers", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "richtext", "rich text document", "", "", "", "", nil, []string{"text/plain"}, []string{".rtx"}, []int{827}},
	{"text", "rust", "Rust source code", "", "", "", "", nil, []string{"text/plain"}, []string{".rs"}, []int{827}},
	{"text", "sgml", "SGML document", "SGML", "Standard Generalized Markup Language", "", "", nil, []string{"text/plain"}, []string{".sgml", ".sgm"}, []int{827}},
	{"text", "spreadsheet", "spreadsheet interchange document", "", "", "", "", nil, []string{"text/plain"}, []string{".sylk", ".slk"}, []int{827}},
	{"text", "tab-separated-values", "TSV document", "TSV", "Tab Separated Values", "", "", nil, []string{"text/plain"}, []string{".tsv"}, []int{827}},
	{"text", "troff", "Troff document", "", "", "", "", []string{"application/x-troff", "text/x-troff"}, []string{"text/plain"}, []string{".tr", ".roff", ".t"}, []int{827}},
	{"text", "turtle", "Turtle document", "", "", "", "", nil, []string{"text/plain"}, []string{".ttl"}, []int{827}},
	{"text", "vcard", "electronic business card", "", "", "", "", []string{"text/directory", "text/x-vcard"}, []string{"text/plain"}, []string{".vcard", ".vcf", ".vct", ".gcrd"}, []int{827}},
	{"text", "vnd.abc", "abc musical notation file", "", "", "", "", nil, []string{"text/plain"}, []string{".abc"}, []int{827}},
	{"text", "vnd.graphviz", "Graphviz DOT graph", "", "", "", "x-office-document", nil, nil, []string{".gv", ".dot"}, nil},
	{"text", "vnd.qt.linguist", "message catalog", "", "", "", "", []string{"application/x-linguist", "text/vnd.trolltech.linguist"}, []string{"application/xml"}, []string{".ts"}, []int{527}},
	{"text", "vnd.rn-realtext", "RealText document", "", "", "", "", nil, nil, []string{".rt"}, nil},
	{"text", "vnd.sun.j2me.app-descriptor", "JAD document", "JAD", "Java Application Descriptor", "", "", nil, nil, []string{".jad"}, nil},
	{"text", "vnd.wap.wml", "WML document", "WML", "Wireless Markup Language", "", "", nil, []string{"application/xml"}, []string{".wml"}, []int{527}},
	{"text", "vnd.wap.wmlscript", "WMLScript program", "", "", "", "", nil, nil, []string{".wmls"}, nil},
	{"text", "vtt", "WebVTT subtitles", "VTT", "Video Text Tracks", "", "text-x-generic", nil, []string{"text/plain"}, []string{".vtt"}, []int{827}},
	{"text", "wiki", "Text Plain Wiki Format", "", "", "", "", nil, []string{"text/plain"}, []string{".wiki"}, []int{827}},
	{"text", "x-adasrc", "Ada source code", "", "", "", "", nil, []string{"text/plain"}, []string{".adb", ".ads"}, []int{827}},
	{"text", "x-ascii85", "Ascii85 encoded data", "", "", "", "text-x-hex", nil, []string{"text/plain"}, []string{".ascii85"}, []int{827}},
	{"text", "x-authors", "author list", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "x-base32", "Base32 encoded data", "", "", "", "text-x-hex", nil, []string{"text/plain"}, []string{".base32"}, []int{827}},
	{"text", "x-bibtex", "BibTeX document", "", "", "", "", nil, []string{"text/plain"}, []string{".bib"}, []int{827}},
	{"text", "x-c++hdr", "C++ header", "", "", "", "", nil, []string{"text/x-chdr"}, []string{".hh", ".hp", ".hpp", ".h++", ".hxx"}, []int{854}},
	{"text", "x-c++src", "C++ source code", "", "", "", "", nil, []string{"text/x-csrc"}, []string{".cpp", ".cxx", ".cc", ".C", ".c++"}, []int{860}},
	{"text", "x-changelog", "ChangeLog document", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "x-chdr", "C header", "", "", "", "", nil, []string{"text/x-csrc"}, []string{".h"}, []int{860}},
	{"text", "x-cmake", "CMake source code", "", "", "", "", nil, []string{"text/plain"}, []string{".cmake"}, []int{827}},
	{"text", "x-cobol", "COBOL source file", "COBOL", "COmmon Business Oriented Language", "", "", nil, []string{"text/plain"}, []string{".cbl", ".cob"}, []int{827}},
	{"text", "x-copying", "license terms", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "x-credits", "author credits", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "x-csharp", "C# source code", "", "", "", "", nil, []string{"text/x-csrc"}, []string{".cs"}, []int{860}},
	{"text", "x-csrc", "C source code", "", "", "", "", []string{"text/x-c"}, []string{"text/plain"}, []string{".c"}, []int{827}},
	{"text", "x-dbus-service", "D-Bus service file", "", "", "", "", nil, []string{"text/plain"}, []string{".service"}, []int{827}},
	{"text", "x-dcl", "DCL script", "DCL", "Data Conversion Laboratory", "", "", nil, []string{"text/plain"}, []string{".dcl"}, []int{827}},
	{"text", "x-dsl", "DSSSL document", "DSSSL", "Document Style Semantics and Specification Language", "", "", nil, []string{"text/plain"}, []string{".dsl"}, []int{827}},
	{"text", "x-dsrc", "D source code", "", "", "", "", nil, []string{"text/x-csrc"}, []string{".d", ".di"}, []int{860}},
	{"text", "x-eiffel", "Eiffel source code", "", "", "", "", nil, []string{"text/plain"}, []string{".e", ".eif"}, []int{827}},
	{"text", "x-emacs-lisp", "Emacs Lisp source code", "", "", "", "", nil, []string{"text/plain"}, []string{".el"}, []int{827}},
	{"text", "x-erlang", "Erlang source code", "", "", "", "", nil, []string{"text/plain"}, []string{".erl"}, []int{827}},
	{"text", "x-fortran", "Fortran source code", "", "", "", "", nil, []string{"text/plain"}, []string{".f", ".f90", ".f95", ".for"}, []int{827}},
	{"text", "x-genie", "Genie source code", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".gs"}, []int{827}},
	{"text", "x-gettext-translation", "translation file", "", "", "", "", []string{"text/x-po", "application/x-gettext"}, []string{"text/plain"}, []string{".po"}, []int{827}},
	{"text", "x-gettext-translation-template", "translation template", "", "", "", "", []string{"text/x-pot"}, []string{"text/plain"}, []string{".pot"}, []int{827}},
	{"text", "x-gherkin", "feature specification in Gherkin format", "", "", "", "", nil, []string{"text/plain"}, []string{".feature"}, []int{827}},
	{"text", "x-go", "Go source code", "", "", "", "", nil, []string{"text/plain"}, []string{".go"}, []int{827}},
	{"text", "x-google-video-pointer", "Google Video Pointer", "", "", "", "", []string{"text/google-video-pointer"}, nil, []string{".gvp"}, nil},
	{"text", "x-gradle", "Gradle scripts", "", "", "", "", nil, []string{"text/x-groovy"}, []string{".gradle"}, []int{876}},
	{"text", "x-groovy", "Groovy script", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".groovy"}, []int{827}},
	{"text", "x-haskell", "Haskell source code", "", "", "", "", nil, []string{"text/plain"}, []string{".hs"}, []int{827}},
	{"text", "x-hex", "Intel® hexadecimal object file", "", "", "", "", nil, []string{"text/plain"}, []string{".hex"}, []int{827}},
	{"text", "x-iMelody", "iMelody ringtone", "", "", "", "", []string{"audio/x-iMelody", "audio/iMelody"}, nil, []string{".imy", ".ime"}, nil},
	{"text", "x-idl", "IDL document", "IDL", "Interface Definition Language", "", "", nil, []string{"text/plain"}, []string{".idl"}, []int{827}},
	{"text", "x-ihex", "Intel hexadecimal object file", "", "", "", "text-x-hex", nil, []string{"text/plain"}, []string{".hex", ".ihex"}, []int{827}},
	{"text", "x-install", "installation instructions", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "x-iptables", "iptables configuration file", "", "", "", "", nil, []string{"text/plain"}, []string{".iptables"}, []int{827}},
	{"text", "x-java", "Java source code", "", "", "", "", nil, []string{"text/x-csrc"}, []string{".java"}, []int{860}},
	{"text", "x-katefilelist", "Kate file list loader plugin list", "", "", "", "", nil, []string{"text/plain"}, []string{".katefl"}, []int{827}},
	{"text", "x-ldif", "LDIF address book", "LDIF", "LDAP Data Interchange Format", "", "", nil, []string{"text/plain"}, []string{".ldif"}, []int{827}},
	{"text", "x-lilypond", "Lilypond music sheet", "", "", "", "", nil, []string{"text/plain"}, []string{".ly"}, []int{827}},
	{"text", "x-literate-haskell", "LHS source code", "LHS", "Literate Haskell source code", "", "", nil, []string{"text/plain"}, []string{".lhs"}, []int{827}},
	{"text", "x-log", "application log", "", "", "", "", nil, []string{"text/plain"}, []string{".log"}, []int{827}},
	{"text", "x-lua", "Lua script", "", "", "", "", nil, []string{"application/x-executable", "text/plain"}, []string{".lua"}, []int{255, 827}},
	{"text", "x-makefile", "Makefile", "", "", "", "", nil, []string{"text/plain"}, []string{".mk", ".mak"}, []int{827}},
	{"text", "x-matlab", "MATLAB script/function", "", "", "", "", []string{"text/x-octave"}, []string{"text/plain"}, []string{".m"}, []int{827}},
	{"text", "x-maven+xml", "Maven description file", "", "", "", "text-x-generic", nil, []string{"application/xml"}, nil, []int{527}},
	{"text", "x-meson", "Meson source code", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "x-microdvd", "MicroDVD subtitles", "", "", "", "", nil, []string{"text/plain"}, []string{".sub"}, []int{827}},
	{"text", "x-moc", "Qt MOC file", "Qt MOC", "Qt Meta Object Compiler", "", "", nil, []string{"text/plain"}, []string{".moc"}, []int{827}},
	{"text", "x-modelica", "Modelica model", "", "", "", "", nil, []string{"text/plain"}, []string{".mo"}, []int{827}},
	{"text", "x-mof", "Managed Object Format", "", "", "", "", nil, []string{"text/x-csrc"}, []string{".mof"}, []int{860}},
	{"text", "x-mpsub", "MPSub subtitles", "MPSub", "MPlayer Subtitle", "", "", nil, []string{"text/plain"}, []string{".sub"}, []int{827}},
	{"text", "x-mrml", "MRML playlist", "MRML", "Multimedia Retrieval Markup Language", "", "", nil, nil, []string{".mrml", ".mrl"}, nil},
	{"text", "x-ms-regedit", "Windows Registry extract", "", "", "", "", nil, []string{"text/plain"}, []string{".reg"}, []int{827}},
	{"text", "x-mup", "Mup publication", "", "", "", "", nil, []string{"text/plain"}, []string{".mup", ".not"}, []int{827}},
	{"text", "x-nfo", "NFO document", "", "", "", "", nil, []string{"text/x-readme"}, []string{".nfo"}, []int{916}},
	{"text", "x-objchdr", "Objective-C header", "", "", "", "", nil, []string{"text/x-csrc"}, nil, []int{860}},
	{"text", "x-objcsrc", "Objective-C source code", "", "", "", "", nil, []string{"text/x-csrc"}, []string{".m"}, []int{860}},
	{"text", "x-ocaml", "OCaml source code", "", "", "", "", nil, nil, []string{".ml", ".mli"}, nil},
	{"text", "x-ocl", "OCL file", "OCL", "Object Constraint Language", "", "", nil, []string{"text/plain"}, []string{".ocl"}, []int{827}},
	{"text", "x-ooc", "OOC source code", "OOC", "Out Of Class", "", "", nil, []string{"text/x-csrc"}, []string{".ooc"}, []int{860}},
	{"text", "x-opencl-src", "OpenCL source code", "OpenCL", "Open Computing Language", "", "", nil, []string{"text/x-csrc"}, []string{".cl"}, []int{860}},
	{"text", "x-opml+xml", "OPML syndication feed", "", "", "", "text-html", []string{"text/x-opml"}, []string{"application/xml"}, []string{".opml"}, []int{527}},
	{"text", "x-pascal", "Pascal source code", "", "", "", "", nil, []string{"text/plain"}, []string{".p", ".pas"}, []int{827}},
	{"text", "x-patch", "differences between files", "", "", "", "", []string{"text/x-diff"}, []string{"text/plain"}, []string{".diff", ".patch"}, []int{827}},
	{"text", "x-python", "Python script", "", "", "", "", nil, []string{"application/x-executable", "text/plain"}, []string{".py", ".pyx", ".wsgi"}, []int{255, 827}},
	{"text", "x-python3", "Python 3 script", "", "", "", "", nil, []string{"text/x-python"}, []string{".py", ".py3", ".py3x"}, []int{913}},
	{"text", "x-qml", "Qt Markup Language file", "", "", "", "", nil, nil, []string{".qml", ".qmltypes", ".qmlproject"}, nil},
	{"text", "x-readme", "README document", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "x-reject", "rejected patch", "", "", "", "text-x-generic", []string{"application/x-reject"}, []string{"text/plain"}, []string{".rej"}, []int{827}},
	{"text", "x-rpm-spec", "RPM spec file", "RPM", "Red Hat Package Manager", "", "", nil, []string{"text/plain"}, []string{".spec"}, []int{827}},
	{"text", "x-rst", "reStructuredText document", "", "", "", "", nil, []string{"text/plain"}, []string{".rst"}, []int{827}},
	{"text", "x-sass", "Sass CSS pre-processor file", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".sass"}, []int{827}},
	{"text", "x-scala", "Scala source code", "", "", "", "", nil, []string{"text/plain"}, []string{".scala"}, []int{827}},
	{"text", "x-scheme", "Scheme source code", "", "", "", "", nil, []string{"text/plain"}, []string{".scm", ".ss"}, []int{827}},
	{"text", "x-scons", "SCons configuration file", "", "", "", "", nil, []string{"text/x-python"}, nil, []int{913}},
	{"text", "x-scss", "Sass CSS pre-processor file", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".scss"}, []int{827}},
	{"text", "x-setext", "Setext document", "", "", "", "", nil, []string{"text/plain"}, []string{".etx"}, []int{827}},
	{"text", "x-srecord", "Motorola S-Records", "", "", "", "text-x-hex", nil, []string{"text/plain"}, []string{".srec", ".s19", ".s28", ".s37"}, []int{827}},
	{"text", "x-ssa", "SSA subtitles", "SSA", "SubStation Alpha", "", "", nil, []string{"text/plain"}, []string{".ssa", ".ass"}, []int{827}},
	{"text", "x-subviewer", "SubViewer subtitles", "", "", "", "", nil, []string{"text/plain"}, []string{".sub"}, []int{827}},
	{"text", "x-svhdr", "SystemVerilog header", "", "", "", "", nil, []string{"text/x-verilog"}, []string{".svh"}, []int{944}},
	{"text", "x-svsrc", "SystemVerilog source code", "", "", "", "", nil, []string{"text/x-verilog"}, []string{".sv"}, []int{944}},
	{"text", "x-systemd-unit", "systemd unit file", "", "", "", "", nil, []string{"text/plain"}, []string{".automount", ".device", ".mount", ".path", ".scope", ".service", ".slice", ".socket", ".swap", ".target", ".timer"}, []int{827}},
	{"text", "x-tcl", "Tcl script", "", "", "", "", nil, []string{"text/plain"}, []string{".tcl", ".tk"}, []int{827}},
	{"text", "x-tex", "TeX document", "", "", "", "", []string{"application/x-tex"}, []string{"text/plain"}, []string{".tex", ".ltx", ".sty", ".cls", ".dtx", ".ins", ".latex"}, []int{827}},
	{"text", "x-texinfo", "TeXInfo document", "", "", "", "", nil, []string{"text/plain"}, []string{".texi", ".texinfo"}, []int{827}},
	{"text", "x-troff-me", "Troff ME input document", "", "", "", "", nil, []string{"text/plain"}, []string{".me"}, []int{827}},
	{"text", "x-troff-mm", "Troff MM input document", "", "", "", "", nil, []string{"text/plain"}, []string{".mm"}, []int{827}},
	{"text", "x-troff-ms", "Troff MS input document", "", "", "", "", nil, []string{"text/plain"}, []string{".ms"}, []int{827}},
	{"text", "x-twig", "Twig template", "", "", "", "text-x-generic-template", nil, []string{"text/plain"}, []string{".twig"}, []int{827}},
	{"text", "x-txt2tags", "txt2tags document", "", "", "", "", nil, []string{"text/plain"}, []string{".t2t"}, []int{827}},
	{"text", "x-uil", "X-Motif UIL table", "", "", "", "", nil, []string{"text/plain"}, []string{".uil"}, []int{827}},
	{"text", "x-uri", "resource location", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"text", "x-uuencode", "uuencoded file", "", "", "", "text-x-hex", []string{"zz-application/zz-winassoc-uu"}, []string{"text/plain"}, []string{".uue", ".uu", ".enc"}, []int{827}},
	{"text", "x-vala", "Vala source code", "", "", "", "", nil, []string{"text/x-csrc"}, []string{".vala", ".vapi"}, []int{860}},
	{"text", "x-verilog", "Verilog source code", "", "", "", "", nil, []string{"text/plain"}, []string{".v"}, []int{827}},
	{"text", "x-vhdl", "VHDL source code", "VHDL", "Very-High-Speed Integrated Circuit Hardware Description Language", "", "", nil, []string{"text/plain"}, []string{".vhd", ".vhdl"}, []int{827}},
	{"text", "x-xine", "xine playlist file", "", "", "", "", nil, []string{"text/plain"}, []string{".tox"}, []int{827}},
	{"text", "x-xmi", "XMI file", "XMI", "XML Metadata Interchange", "", "", nil, []string{"application/xml"}, []string{".xmi"}, []int{527}},
	{"text", "x-xslfo", "XSL FO file", "XSL FO", "XSL Formatting Objects", "", "", nil, []string{"application/xml"}, []string{".fo", ".xslfo"}, []int{527}},
	{"text", "x-xxencode", "Xxencoded file", "", "", "", "text-x-hex", nil, []string{"text/plain"}, []string{".xxe"}, []int{827}},
	{"text", "x.gcode", "G-code file", "", "", "", "text-x-generic", nil, []string{"text/plain"}, []string{".gcode"}, []int{827}},
	{"text", "xmcd", "XMCD CD database", "", "", "", "", nil, []string{"text/plain"}, nil, []int{827}},
	{"video", "3gpp", "3GPP multimedia file", "3GPP", "3rd Generation Partnership Project", "", "", []string{"video/3gp", "audio/3gpp", "video/3gpp-encrypted", "audio/3gpp-encrypted", "audio/x-rn-3gpp-amr", "audio/x-rn-3gpp-amr-encrypted", "audio/x-rn-3gpp-amr-wb", "audio/x-rn-3gpp-amr-wb-encrypted"}, []string{"video/mp4"}, []string{".3gp", ".3gpp", ".3ga"}, []int{960}},
	{"video", "3gpp2", "3GPP2 multimedia file", "3GPP2", "3rd Generation Partnership Project 2", "", "", []string{"audio/3gpp2"}, []string{"video/mp4"}, []string{".3g2", ".3gp2", ".3gpp2"}, []int{960}},
	{"video", "annodex", "Annodex Video", "", "", "", "", []string{"video/x-annodex"}, []string{"application/annodex"}, []string{".axv"}, []int{3}},
	{"video", "dv", "DV video", "DV", "Digital Video", "", "", nil, nil, []string{".dv"}, nil},
	{"video", "isivideo", "ISI video", "", "", "", "", nil, nil, nil, nil},
	{"video", "mj2", "JPEG-2000 MJ2 video", "MJ2", "Motion JPEG-2000", "", "", nil, nil, []string{".mj2", ".mjp2"}, nil},
	{"video", "mlt-playlist", "MLT video playlist", "", "", "", "", nil, []string{"application/xml"}, []string{".mlt", ".westley"}, []int{527}},
	{"video", "mp2t", "MPEG-2 transport stream", "MPEG-2 TS", "Moving Picture Experts Group 2 Transport Stream", "", "", nil, nil, []string{".m2t", ".m2ts", ".ts", ".mts", ".cpi", ".clpi", ".mpl", ".mpls", ".bdm", ".bdmv"}, nil},
	{"video", "mp4", "MPEG-4 video", "", "", "", "", []string{"video/mp4v-es", "video/x-m4v"}, nil, []string{".mp4", ".m4v", ".f4v", ".lrv"}, nil},
	{"video", "mpeg", "MPEG video", "MPEG", "Moving Picture Experts Group", "", "", []string{"video/x-mpeg", "video/mpeg-system", "video/x-mpeg-system", "video/x-mpeg2"}, nil, []string{".mpeg", ".mpg", ".mp2", ".mpe", ".vob"}, nil},
	{"video", "ogg", "Ogg Video", "", "", "", "", []string{"video/x-ogg"}, []string{"application/ogg"}, []string{".ogv", ".ogg"}, []int{32}},
	{"video", "quicktime", "QuickTime video", "", "", "", "", nil, nil, []string{".qt", ".mov", ".moov", ".qtvr"}, nil},
	{"video", "vnd.mpegurl", "MPEG video (streamed)", "", "", "", "", []string{"video/x-mpegurl"}, []string{"text/plain"}, []string{".m1u", ".m4u", ".mxu"}, []int{827}},
	{"video", "vnd.rn-realvideo", "RealVideo document", "", "", "", "", []string{"video/x-real-video"}, nil, []string{".rv", ".rvx"}, nil},
	{"video", "vnd.vivo", "Vivo video", "", "", "", "", []string{"video/vivo"}, nil, []string{".viv", ".vivo"}, nil},
	{"video", "wavelet", "Wavelet video", "", "", "", "", nil, nil, nil, nil},
	{"video", "webm", "WebM video", "", "", "", "", nil, nil, []string{".webm"}, nil},
	{"video", "x-anim", "ANIM animation", "", "", "", "", nil, nil, nil, nil},
	{"video", "x-flic", "FLIC animation", "", "", "", "", []string{"video/fli", "video/x-fli"}, nil, []string{".fli", ".flc"}, nil},
	{"video", "x-flv", "Flash video", "", "", "", "video-x-generic", []string{"application/x-flash-video", "flv-application/octet-stream", "video/flv"}, nil, []string{".flv"}, nil},
	{"video", "x-javafx", "JavaFX video", "", "", "", "video-x-generic", nil, []string{"video/x-flv"}, []string{".fxm"}, []int{971}},
	{"video", "x-matroska", "Matroska video", "", "", "", "", nil, []string{"application/x-matroska"}, []string{".mkv"}, []int{374}},
	{"video", "x-matroska-3d", "Matroska 3D video", "", "", "", "", nil, []string{"application/x-matroska"}, []string{".mk3d"}, []int{374}},
	{"video", "x-mjpeg", "MJPEG video stream", "MJPEG", "Motion JPEG", "", "", nil, []string{"image/jpeg"}, []string{".mjpeg", ".mjpg"}, []int{608}},
	{"video", "x-mng", "MNG animation", "MNG", "Multiple-Image Network Graphics", "", "", nil, nil, []string{".mng"}, nil},
	{"video", "x-ms-wmp", "Microsoft Media Format", "", "", "", "", []string{"video/mediaplayer", "application/x-mplayer2"}, []string{"video/x-ms-wmv"}, []string{".wmp"}, []int{978}},
	{"video", "x-ms-wmv", "Windows Media video", "", "", "", "", nil, []string{"application/vnd.ms-asf"}, []string{".wmv"}, []int{101}},
	{"video", "x-msvideo", "AVI video", "AVI", "Audio Video Interleave", "", "", []string{"video/x-avi", "video/avi", "video/divx", "video/msvideo", "video/vnd.divx"}, nil, []string{".avi", ".avf", ".divx"}, nil},
	{"video", "x-nsv", "NullSoft video", "", "", "", "", nil, nil, []string{".nsv"}, nil},
	{"video", "x-ogm+ogg", "OGM video", "", "", "", "", []string{"video/x-ogm"}, []string{"video/ogg"}, []string{".ogm"}, []int{962}},
	{"video", "x-sgi-movie", "SGI video", "", "", "", "", nil, nil, []string{".movie"}, nil},
	{"video", "x-theora+ogg", "Ogg Theora video", "", "", "", "", []string{"video/x-theora"}, []string{"video/ogg"}, []string{".ogg"}, []int{962}},
	{"x-content", "audio-cdda", "audio CD", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "audio-dvd", "audio DVD", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "audio-player", "portable audio player", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "blank-bd", "blank Blu-ray disc", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "blank-cd", "blank CD disc", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "blank-dvd", "blank DVD disc", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "blank-hddvd", "blank HD DVD disc", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "ebook-reader", "e-book reader", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "image-dcf", "digital photos", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "image-picturecd", "Picture CD", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "software", "software", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "unix-software", "UNIX software", "", "", "", "", nil, []string{"x-content/software"}, nil, []int{994}},
	{"x-content", "video-bluray", "Blu-ray video disc", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "video-dvd", "video DVD", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "video-hddvd", "HD DVD video disc", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "video-svcd", "Super Video CD", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "video-vcd", "Video CD", "", "", "", "", nil, nil, nil, nil},
	{"x-content", "win32-software", "Windows software", "", "", "", "", nil, []string{"x-content/software"}, nil, []int{994}},
	{"x-epoc", "x-sisx-app", "SISX package", "SIS", "Symbian Installation File", "", "package-x-generic", nil, nil, []string{".sisx"}, nil},
}
